
# q-expansion of newform 9.60.a.c, downloaded from the LMFDB on 06 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 9
weight = 60
poly_data = [-23358185771581696169459363194340724736, 2677795447191606098169599438848, 9065173660301515822976, -3976283494919360, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0], 1], [[-5, 24, 0, 0, 0], 1], [[-1240490506653641669866746605691392, 102314614596804580479814464, 2141374975420432680, -37846914417, -567], 12765437266362368], [[-12935363537448663253118554131751424, 127459407364152524047862592, 9494266840845156648, -37846914417, -567], 12765437266362368], [[85338870566699595484758853274423418368, -1420335560668568034930714332352, -200258777797909324704216, 450652208893551, 56341737], 63827186331811840]]

hecke_ring_character_values = None
aps_data = [[89938373, 1, 0, 0, 0], [0, 0, 0, 0, 0], [-35992322464951840573, -174673144666, -213, -12, 1], [299755508987031105041276, -1403037836233582, 51206374, -1472240, -7020], [-851695669902420903572147793812, 3739937378890595748085, 10024580618085, -3717411735840, 2748847640], [-169122982979244319780959788214331, -583738822935191800641542, -3097561149712155, -198523391408180, -476711357265], [681757826654523939237011486660295076, 219750239787708234455511684, 7777130488502711538, 1778018042496512760, 2173189785854230], [12922711109406796869162748924690289708, 8728717018956666952797270293, 2533851712950979781, 6757617129034581984, -57636170473930920], [-5352443879580048997915132616945549870340, 8339667397111419025762096789706, 69631813378176681696894, 17882672020648260992400, -3523640114226532300], [3509809220779428808782652045901268791821463, -4696622324945162712310730730613682, -77525548342426515428928609, -3008660373054039777685596, 11093472816986328406365], [-71716724615043046148197917543211201737040768, -33013741982821011344904165219523480, 536422256688045779642928520, 4243881542623458750785920, -4377107807206549708320], [2457930939701283892692383822849148978776338865, -6884594595905954359067225273548211758, -11412961991101291451215640527, -15442139686318742475421312740, -22226614560249703859361645], [252920063723315044049040620203172483472581677378, -221420627007395450505986863199270317720, 2771613866423939860928923125780, -42035379933334144449495975120, -283719867309816934023526980], [272480280634424204367318530211116844434328742652, 296504510670787168422854924386641783651, -941891868302446862981769295717, 234636592080945310714249969600, -2345372823932992460476069200], [-11623263018092376142982018930760925825060788437208, -1323244354663561431548602594559657698220, -68977722086625454265473109795796, -17814261754442478807286142887200, -16089256723404993087692090600], [-453620357720861435799334188371942498334866113172193, -116123315768939685389944259225749449203922, 716526719339086427880855706220751, -642725977170663875174201118939420, 411878878606039106370571609965], [4386330675507297430163885021093586659130633540035396, 11995692062376821896022659997253132413102921, 48855610900477679169657933308084097, -19828043556958160450813584555577472, 4363770674739529391907552412000], [-11118828157822574087761100128781287595228186576630083, -35040547572386476526483764808190346983244950, 185322665887220151935697503369560925, 6545089703030546401100060820760300, -2664481136938282724928678952425], [50345791684427929335515781055260504503677809504401564, 201794548122392675573841785888897601806477681, -1709899102709970052610594375577551423, 259444535678517697198492860544438240, -818300791802226734323992467277480], [1273919531947238243245840046543246967667434559128849268, -1254975950243538759881389892621195027580163650, -4641605113158963957855642741286458150, 1624731671157109962455324399021415600, 3851608080459923789916554174143900], [2499746823102375083458177723553769604257361161481029260, -2510020240328564585901400275471743000261248596, -1332940213759049256683977113344351514, -2176210408633157058650142027106518360, 15175739361627782741772581868281970], [-39005548747964057991281856099989372464685992903661047528, -23818634024602616666996397176135946466757788268, -848802325200236955834516903888353348196, 26440933847702854247078371396598559136, -121761731571365798338342190990035320], [-268150603502359498368273421028580331921258153437697237396, -15982277966068463058869579965427169969336712085, -1381153321703501948305508075006003759757, -163103490827775692403860648312322624000, 205365358141479381607900159449648000], [-827598807024436870791705491959572298155137987897881363996, -2407574772892199566289059178031498899219895378156, -15167491509406006442698217101508044550022, -848446254592061737259165188967180899368, -926995877175493700463240053771509330], [23300548618205531120046281697984513099428684989074411887828, -8564441028589182087452558912656264588728132496980, 49497438896915396040520352147127424035686, -41187144239603605721978669911155511128920, -53795434171159165063991848791819632910], [-36430524207696882975888618440487294668903337562669172365017, 60837068875081366345691632485727445729968261620670, -338375882072908859173549414752844620897705, -81565866960800370698888091657237604485180, 25559995209275331208251396877305382405], [18829966665439980060350957239877475747800389918862121443708, -80195419228903647078105415588580495663402702417078, -1869415454335316262681438144844908252194946, 65441865611107228119919273059205454600080, 188058811497999635098256052578923100340], [-288061772742424465011407970893219930317809938339175018828516, -444158761754233641909050761567546706373909137065443, 3712310671161408545719078581463272583029021, 701361557905046267280297365486104474651680, 185747667810287050122373862658335369640], [666497429567069073794721903976028448688481899659046482674369, -848578547525883220196753313760464821795832883685086, -7563580402979427167022595535366958168080167, 904274214828160389709587621051215217659772, 1287345207150965833986204096525046887435], [1931295993832657092550778390710166414188390723066276389898046, -860873524994106692197175963052546528891810769636768, -28301616773418149985132950690571919363091280, 1485846063752430493614675452300554217858880, -3352994477552800670819260931168288779760], [-40487424203007254572767703655235730125650870728633640912059888, 99448589621321103122230602253253990733256977132508544, -533860191423781931709437362526298904765025200, 79182916044229391179708088053027674225188160, 123667261125090720877193062704434368609680], [-72779931668179777339298445917994537112314611555913913051747692, 57177929361200766150721500913293927418201312553370335, 1276641251908404984272490992019288808852438335, -32121241291279047435083898815294639653143840, -229839470581950045407978625381617274160360], [-62598432112338220622078677897363474638040824542373000542792590, 321692977213053285215761120227778732001843591727567688, -692840381889641720130060723843364146376949628, -756789417760539321412965249523809741424014480, -269321538926637822299669321455209449271540], [180866960106519927935148367423685473209121786880259538675707836, 724172657179421509117159869812054636863481602572985691, -6353875664870601547443701259947640056680173773, 815550109325889752534707192355889278722408768, -68301929756989229433664822231132776789360], [-2498408806948529153276464271142713946684143224007491793200823165, -1182301455287190519153530794079768202526452599886525370, 59599604563927913008848494791581615847728492795, -12752704893972560554983392292612080497686750540, -6328926295366476436201987732954742770608015], [3174916674800364283201558756289609927892457631583484026603292292, 2577327520965971591369399974511036842043109970140086230, -17538450979332620824366745725174822006281186270, 27541897409695916779478170666907805202440212080, -14412835333066543047609498066740678984016180], [12401419772095336522946310228155000696557538394366246638593153541, -32604687133073426066306591389712437049842135511329562022, -321710465861114404243843318905103981946727549931, 32309497720109945928721076813418150295509645580, -60071846153388460306424703476421384990958785], [-147207703333056978622179189018949635982868139646027685641931385676, -70673557468134879813984759690369494908490675938269167047, 353599487028947679445239261143396506292003701985, -54030274636176124270047658864922099659071195840, -27246083528557972171862793325208148882142320], [-13792060846579540515249687299752318820880644592371947955163634924, 43512309848139656955030426617335479482483992650129779654, -716080228829025991106134557141268875982628290782, -301833315737256808790719256228451356320087901520, -261227369117052998449529079028025769791071460], [-302564218428739384105417498764999297799026219892723971691321206365, -315746222067451651047160048821810733923330397342808993354, -2096239866205735335999123501067530995713190633421, 835739015624724501482156591109516118767108963540, -641916449317061556790402886328588980322212455], [978275258460284909220254200542888321695283301049003003804589350428, 1916770961772337693970793497468083064976091784482418372883, 14628098619083246141703173287070332620186392313771, 2553804236940538459000968435256684825145253359424, -548825960867887272372814183573516470634238960], [709505828125516968051238992980880391313818298183188526660749070597, 1527945823552043191230106114848723483057354622298569236650, 10172768137657639088699464108121553020195707598525, 437878218638195695051915600849801750593279105900, 131400023529889427474837140141808888378817975], [-1863809232901256923844650798411531887306123448534743843628400259952, -4732014309698220294072011469198336244951344266077739092880, -24359207567620827884134791095604202131038746634880, -2388852989090410809623308237174408681012630764480, -21143162105546581549123740591223665710094271920], [-9027421026013240495892534916925667393702805216824789658451219826428, 7703406136669400158138948503881038073258527710982392113676, 299270802654140444992715710473061552185948378443798, 12788767915822385758714243545918760300649395477480, -26477181929766932374748387609574889132202515710], [-5066409332628094794836147452176205158800227252798603351653814731253, 9155933708508162676837250700166052085102205911362255242710, -26298796057987138426393471062938715465754413068541, 19260927105919801917073430282020664703088208951700, 16157843344465944927500219491551439751849177225], [-34852760443687600442234988200405554493068591543445808220117522003780, -19779985501370851228583263215491982864556499381979715838590, -592659381857972666674521422729091618790477159456810, -26641935674676733420771571815611738591788243159280, -55819501014781224339264113322876991423842367980], [26439251212255363212012212396506199736771413830651313909520366248132, -48235602865844868786144131994495912657486803850966551293995, 2927924751232025592670724677036196924423146735155005, 275823488482565009071050970468449105887609062828480, -276854626582780540918665801948881686836018256080], [-1033329243121329384811725155051200348898636140502443430051688490124800, 502952974919417918185438314635162633226385353872165222006744, 4066855264904314920909324740351229700004359019217976, -390665314925914045831851131760852480460151582399360, 2866681752261399547936237013455208350423060002720], [-1653593841329988138818779208188544792007099307102059586009637208631652, 2372927549404819407170498902128432256179538261423399133302231, -11270364027060461003188890790863051308038144700242305, 1546283258521419282798535426295239239667808479994880, 2344097377659377332909402307123539545341547818240], [-427126298213692120155365074735897194088806312163961511555737381146603, -1187269877968934368095709791944435929230384064017446379893078, -14312050822751651819247713163505146424997610798341571, 1643819741804331680849773174020221060931414910943596, 5474512730581845493075289123126771083286651045175], [-2966095128967078792341122781691468885068563142899770121445337625872316, 1311504854596584070339266761117375315183767965423995826202740, -35293878281176402830325218756211676953107885684737622, 5811118943583599546195894720379331326764533473597720, -2051346986678073839087531111240938154475956714690], [4256071139010532279515241553323985733621825885856471274681983943526264, -8686487441046397556030167184364375438677184248239654152946876, 66027781638472123730352925114340554357601729109632748, 3719257167223453733337058747981639574141698683343392, 20762118597506953811262247203012445594219145079080], [-10119950939415987718771270329286306949801877677549335877810020490633188, -6983398373486462075262887908379414867509839890998151288936900, 29432905410700429178211275873260608944474607724234350, 9786986631384356203665849344601209857797549795742600, -8937396127488261011202597903997148707912508143350], [8905637517654576157827835986169533456604069751143794599983956259471748, 9458375294918000312218040689339887093854530893276825424625625, 163780956172145643447170133345429979163174979830708625, 62496985569128301739082770169426667446193605263536000, -18485218920630618951590955081699918220717700452000], [29043457743646187096209773308628046296157139923204742037373364978322814, -72178118625215347170700681941829903000095623003534028689337088, 1354184376783676203823075195110842117849079091917614976, -48921777548793928703802833946810254246437105788741120, -69021425837402149693969147458545557953073094309760], [-40125601207319352227640521054430604107748176451269048761755926587355084, 123430455462297725712361497685853539657339781156529308899091662, -254918159414333275750966874798556364190548659663131670, -44383098946324766295053593559525654999895769126324560, -146389678087622105229229637974823685831735228369380], [71452472863901776180859469937723968091753405344887485560317381847207207, 727070238181538035156438798612311715636876648242360767870862, 24770769346898574807105902410764789032582971751358399, -683862980762764950448376939797754374052258651578947804, -44704703960118894581328125899528884463124103988035], [15812534655931032235996134510932833884445966640986053714367431106332392, 432724386757526142516060847918954820491358152180324575657490020, 3229347142496495166620190358735542279158448861425737020, 57567864211310907779077185438808853248624090961821920, 313934656508894834546339168230193787314179222870680], [-450140822382563705260036869020928864484185927640043847813286042472556703, -800422902007376917555872210841240864790173280471260231171085806, -6853319149427989973586434113452117966773544130576670255, -624146632325047877451074589555051519293858869051628900, 366230947787732575617402769949660078847419383554675], [600889532902754444688868455390453407827360525829174864982121838296898668, -1680362391741855179644533514453098611096971757950055430032284220, -2121458183423289288027828029391940283841796520265343470, 163770314553941251842650595327029112076713749768117880, -625958949253887124091215546663304192011728566190730], [1134214643426710455965006049336142849301800810387698520427138661893923796, 287642956503030767508454014350656606099493480865620181574195615, -2658081558248058310649943553961320230104932639948359873, 766617205105905113495541059990512130695656281274304480, -1255346617302125461377395758760744440616449356705960], [782463197052440836605920998906073425214033057679427424008283964723363483, -2650290436302295388529741842734721181255364729248702430526071306, -33196131882514527449830716998170797817783019510952026733, 236696068140875457445810040071223308819847047031045460, 4479155263972119974747838833896315370845667612315705], [-7950289301628712551230290003920618914422809745949315879012947321854248404, 4182596423254825719056252522919588762275097605276278987981437693, 9945421399323388039138445837927582529815321621351418189, -4188436259427403325155268022877435394076471252820428960, -38253977337563874092490976609030490213271656822923080], [-9335374184931626896363285946055302526753340037144216251822639411576308452, -1587077634915532827684494688190354182685744027109947987661530270, -197917231786399881822537920837103465497770333446904033770, -1048569145894760284081821760165978544248818842204503920, -36531215734688280589878269668511262081695607810183180], [-6920069976222500339776003245464533152427398022807845691571569897049924146, 17055946888523202374416174754299261183401504678814625139542879448, -37235900581704701888247212297085174311699255320446464500, 33876361086114346616454228222297682112509334843213650000, -12155413074770028554760988483049083282871549220337500], [-13669276434224973684845582078231358971032825134360691033719376327722012969, -8687652279996157107674624495608840109265924774769188263401646066, 603755636391929210149453041291897460364960309923448074623, 7317863646574111514733839882052134622395101188599890980, 13227354514589940818383415183879451809332264485799165], [36188879413096096337750451227441947557477779435587072854105111023259115652, 98165134805337502913622548179556660418821698278138989579888808635, 473846436151523254679708295288351087837529231316931704635, 3268977326652184170836594133701270908141305762870388960, -243671777874952914338171748522156059981695708444685160], [75713115771672893063814243013626301438903583122884537900648433403312719130, -277963892879234243162082468878090509877278089331154196143716145168, -390545444987809780164640636071262251001221369042559981512, 79372015870885136655782616345739059969521132654053219360, -215914031901602552958054853322518610578466891711877720], [-187375496190135363322436354291288041607331090064378513147919755955618585868, -424392514469664845145059631190070028982909457132753996838119470975, -440116688013474260510961791238212072020756044191227048311, -388971141277467658801916358781786395300089742224881427520, 1338194518968833959102740063903920889962559772509253040], [-389548673049628767760333303960858248251264682627034013715643560466270895695, -43803896968121834510121789895265364978089925879046800978063468830, 2091845188559775213369962336746119471714019326060893929785, -198287324484153253420047239160771593768662147712453495300, 463843670524200556881867406119169991188782410513802795], [790770714185491222376312176887571588060487869296027451192225167457881409622, 991538976710155082392072428666453539567575463183226564130380910288, -2383627505205225206952797944643982779063472152501036134104, -62527818624129413037406095485992746805923816084305450400, 738876741107381120249036379625921453582800001161415800], [412207010964131445648090445090535588460684749821529171915514837010179932996, 405017177055920224069214961616649821054099922835818256189578699766, 5772383130476275006525467782805676663450234780919435029122, -225886417728483307756435132749327813004875793543431810192, -3186073187681126078232069861080925639148855577576695540], [-77656074941953913328152537404424740882282712957105245886217261419688124456, 2108261581505617933800809209096101473802465525169795637465643500476, 15628864819880856649730155514281619111899125813786481510692, -4571612376919919731066180708124274907280364393256338199520, -600147070711149280332551385823889549738295747996687960], [2283406727524908822318348542839026162682631652995736764690598447357790156265, 2174656823391821196053497471773441680996100723572086364570925768834, 43031508275514018571262288549309731385674375041418747552841, 4392535398156136769193709280155494197438619441271620638140, 3907198087306618018065001870248034428031635780348389595], [9418442997385631864328997008871199893666784608570928597886796042638168503372, -4365673185670979372088833220056122633600478786863482807263544285913, -16632348409004253904971684224294343431145487692517094526721, -1647434433416156883894508487112702651536151977292964417344, 7658242594615341864786693781070260502098103068236430320], [-13230518679961132917908719266874514003906348790807758496074450509545292714816, -1748705113825696746266893352818244047210909593610890311611024705120, -68254158333909870689366267904230992995053256563518437383712, -12718324017115943577579452377456638778151556622426877571840, 22948312962897513250790924998652707895705811396167279680], [2584561572863987512920783998253411967474390087376422767043698536751231352639, 6297772489830834725171179583334453246567019317769321121037647534734, -192764038581678181725415540784352386117556890927757636507777, -10290204694146620274811460361999117319741305160711192456668, -5061858564474077344433636262324492073613719677254422915], [-21570413994018841482289079823810013390765475226031745764329689354899644038527, 36218202658979878831863993410886002796136759708694578771839408675170, 417710405959888848748235388788501013996952485795944568753401, -23375733717146006191721912990084386749829938611334182702340, -31224148998699781738346590254328762348126410107062487445], [30194568756567780899804339979394057020382949757915475548571180556549807663028, 16289860286683732222005729658787190140855339085948340196375048191460, -417716674475629502049481857654473393756710147371176799341790, 39488819592267743883034335387521588099398591115642758319160, 98663720156373869387708524836286807051988055098441300390], [-97349996002041366638447036458704677697765451341718234884730373605522418377666, 66967992131580073225556017314103928889004460414076080836095637450424, -125906306208045665173557849040002188197996360642299461742212, 44603984517164794978925988589058419736679531388848007165072, 754609078191691105079302905871713472080531075354546420], [-151782924388824783908958840219593447562197037283021796031625276401889786344188, 126798301351751097402166620355198152859423452580569717290710593955607, -583573595254688378991689092504846880333244795435218947310841, 155151583214703382686612516757100179257848647495470745828896, 193408221395291639663956693712436131384954827262188113960], [-142924550075512563911602821309380488283710343553045686520318703288190042952883, 39613610985018090034406841658160403139020085756450171161581357467770, -719138388081756419196779794564900319890796824306625834211355, -127263860407258123835934196285035231902554119176047796182580, 84458413684904176004524008344501563921012761420370763055], [1101038950558527027881041833506089703910971123694638605774584534195228439608, -337658129253767501986938555725139082297943622868922472319277878650540, -1427529430691698062135416308346869648049853737457806444577540, 574711202982616424426899290834101579064864752464684043312160, -310043861036374215870509270283745810694205700535501046360], [67549163242418518413718014154120040973105966782553904449146841365045173341356, 363739998131708378507446675805688234925077671024074968093833722965020, -6677359321214406531295086577763017288040875371609094828007458, 140448940118430892516762365280739043324540465436096185645000, 591812111452853625998120043452321540437457803410469436250], [431221119953951638841201801866702347145261446391526275699634245953825935478116, -149910385670837491585370993015928814586776620242450666353514642099394, -3632593772024581772805068345068445251356902637216102263838838, -167244568504608752414924740840445025880153086305750178603152, 769506339888489757058023601922270891681809878676685662220], [-47813888309432432427117528994264994862300373876443735821713358078343389708612, 83781174723853118763702429806067589307758797977543472896747755112569, 2201941177849212981947103194864005474784674353507129697834377, -1610114200711755759879222644440822726688523983790137702514720, -496211546490328443704930591540515973156683520406166907560], [1439896670405697617897281020992729453240754403500594765151371429930267072483100, 1459554124527221241515107866633049659638565242761109143151387239603380, 1095567462692247668497635217241088451531241756343914509298250, -571396801038892276996387251241482850046876892926297334559080, -215154413341352760664096928241027526272634077451241815010], [1497950972183072232781843255987059418004129963815658109451635409641750951964046, 2203305212103566778068432268785299008171078664634096672108146937557048, -487801757521309884240452016647236092273407580874760639870916, 1081514009435943278817590181301134716689211435158467770450320, 647265834202456044536548081315390772253361444906576663860], [-831326313160148877215785074183402957228170660000692947858056296053481106959657, 241961607199309794795626078735936046377795603096951826871328789985070, -31353988508556350794654920427164131739521448002571947382808305, 285467612744460595015315766603751767792517801632081547317220, -1793755169828511342667958091789987428810584953764979142995], [337569322902476277058253951255100246692617785698375775105153894542853997709144, 4369045730241760823219976284000433578776086526945140249791495664550388, 2708215061163174490075595947723583747026299829324462406193340, -154153151257058649342987361916114465131073550283927803740000, 67659971470752523239271338944584192549341806659463325000], [2979543066672951589064973322812829891714991029334764380213742772408996058727556, 1625681781904062079225794264958618910514065302146514152559104676863579, 21059612904015594435027535220773368453264640461240367789459803, -1825216942410693740801908488129007444177616367477723133274400, 2862706733830671307960545429529548292668787665720259083800], [-3631880657525841152066570104542725434021315325204278569741124603197359849992512, 7579249861826767770922829319797377888141373897800288004434362261887848, -57912319671367382523766277269037112489984140443446316781091384, 4593120420131913952023078540898437099335281035679846018602624, -11809201852206384000123970199079288125810559579418309898720], [-16895290908769039720146048627610066054593676791502353394440761092125712511535700, -2181035788186559372406185955602555720992621378723149986296629296479798, -26893326387868606668540494422139586861685449917938039571607442, -5477130037844061741329572232154967836316839992806794825816240, 20411422563713326279211070582971734489484330894857214170980], [5617873727044792601866684711399811489737101362767935865188834497594698112021108, -376028493272941009524089625721311812256662121340429963872333127710835, -13149957102442436396351994140065493256219928095001142886443835, -8849186805155091674485013346271687220746245418895894567324160, -29228679337042486043035140933671082524205618253226702656640], [-1431366345885697516142210167360138029067856354876181016874429668901756645595340, 4425739382537454815421064291955615667217154900408452663631259183335645, 259969011025926226251948656088272723889338419973764309346093845, 42178814235211698199796578065883699198664146651103521536056320, 12425112484423553576212226439129578365455886730776805978880], [9709349093318066666044222322528351876689292443006959996818537413385118493300972, 6554651530033218985752024841735997729601292242381214317688277280068178, -16203371843819361290405564137473125084384299958071570608365994, 37668382856052448874883800509922737723436051147579449951231440, 87754291623059994977144032909860695649000798686907172703620], [-39927505710504963141562753842199827996252384198037300726587773641790398584865749, 30727798896309730273112355550116773926765474660739171886051810656516486, -539308664101885776876212587262908030175937768359269656717462693, 10633679507444797390594800133562911431779582760062343736691508, -90024872772629134619756150184908623601003359283235998867695], [-62205188081684339322219293536231369763001917812505144415178918629620763529762942, -27363234122074633493308307028032693710150672231488646829153219531148120, 493262807409052427420280659236642393925241986385238643849299380, -125074428509088131757453112379553349631621780144707913364125520, 101045003861899817488648790568698024149593058389452643083420], [-1006672313190042326360611207755526579800374836137709776161929410625029397602460, 15880666845933274968120237140963266529219092084186724933559544434839019, 452618406321658164975433941816707830585467142376360028227451531, -231610381015897324703400340569482051939365817784890220893988000, 81578960629577505829815956350764001038493646765047372611000], [-116685101386415708194118648774902508030639229922821220570740233448615218619708643, -40093217520139338883277843923322270540557078248762525361906121752677910, 1082895201095142535285141456976785841232572156892277307168535965, -82865745355780654486029519328325983609114469064972429694435860, -72873750159209869095103044171758131838668435094518089889065], [-133483120298124509069969322984990610873768545032162675148440444586834892831293892, -431094986232935519786732001063055052192695371617369056184895780718443255, -55380408883288852576715727529810942632101291700326416788336679, -67334632738779995194948209420980916496390624009934209970304800, -611625308857911153573176745150609487905144755658781051415400], [760956775516790891352284786471465929072706515347022008916210378407061156907611099, 440522468496822587557948149267496821935334879268785052408667872060847622, -4560005459310049956512223913878884580262865252341360421944117989, -538115522647699364126172933607751090063331192848481690998966220, 355304985266654573821657395444209295664028288159570359946065], [-839411968575759302445019892475854254580315949443731463244781578049558693740856044, -259390558011586011573645250875353203748045053494953285859156051284760253, 8614650387525670460360606557778305415421786258034066580110170675, -1061946575335794928834209309137456214570783705715374299677100640, 1053435550179969146828173668231645115436161435111347552742280], [-826220293080988020249015588415454449554449267737780444839056565251447521607633998, -846966076713701285380557716366039668707906778845515948955927369691066328, -3815386380935886559358176373527295792474781183211728984980394636, 936171014854090950493475377915953934633507196045469723574800816, 1949542938875353843348823218986009746978976919884121536746460], [1067049675307690995590831510659050537314021807707105252366901908597872787016523812, 754527169570114360935817201444378320201058229939960793130698325267820135, -4630457539977814233753690270778312049776646205506852414003089865, -465463409511825355838521647175446945971021775746302671520339040, 870634305744981343276513998664965676013340384148292606424840], [-1228099038703456158628088520363893774776375473577415171773523038622272023222091318, -2460639487174883820385572747404832975053642949284916517203367575311245776, -976197229347531921953264917263972208675843657664972881285654440, 2716983733490589376226989704492522622741168718454370314593826720, 395201509171138143965407616650548417851917507670713624663560], [1301121049655979177927641017474241491516468231064173145660013646931578733299074540, 1739215828116534858505972554230150668104940316257903290351782453849008933, 13766701212693791263788042469071482502121993947358881756210810837, -770453889179363764693745236037203029988871818744672153270225440, 7095097390961381006681804689867808049224352466582202693361880], [-1594857111714468809454039531181212266059904802743012088953387397942701716414440642, -4078761364582433952034222715063809903805940688783870983780744327541802976, -2793987306743422799724461246030661412187235892236118029792767088, -1125618093174399712260947878353552895218354283734575338190391360, -7612736711409648170017095913397209789520260139671922710163280], [-6326746895646296548976674912478173868241082555159021930596825161680392189869795380, 3754399631388777636723466864409910276419046111396229138519091511402573530, -25133286797070116762676243534976127124685763095207248115262235810, 3296414902886995895665778801817075063701920917381449031197422800, 2726257064107690837360256692634976383309735003875182487987780], [-3254537719908590601030201182391394653629365091963140470191743198874692295754382948, -7461834728717097705010550578266075234141060324703744697163573401047431700, -72739839353454395439319231977319598540889017429926873050355859450, -4751616052327795779636839711663538874317453173606164456519626200, -8186115955119449984836849483942289504698637556390998507285550], [-7939932020054879018996751260736331146739849033640381769055827239773005461309732944, 10982673239125584522746504998897514290372451703781695960303971042228271448, 101111676903501448152247473137819092674308820428217154495164731304, 755701790144780247277189023387799030553958737428727569114538560, -12332283610521914969231213801094707613835414185662036658051120], [7429391977449735981849887624674968177320029973955483735259152994517013617069755949, -1237054352136074132275742229723796579445162161732532089477308802026495942, 17101705957400321842200233219925883944981397523925640041069649605, 15796349609095230033036622508007756221240436221270172707849521740, -8496574159899967750610302832300673245401854445539445748205105], [12353866819952685873763973208130203436455316410718679807060205963563895369781378476, 756937126243914461014544243048632113558312400636808104198777488102139364, -59827832751615954469951822274402843136876088508736162762350171742, -18853501088553026439014211107133565848477160667589475097494677960, 3482145523995736666934696886015893982467966169518926416133670], [6755892369346984494180702644654480269097038433694055168391399894029048028203990868, 1113440800726817395625312793246611828149414342207337902526210656725633923, -4578004536784073040522912594058900894502169453715123117047459149, -24544047268864043575905905461849606621365652918617501748915708256, 7899351748611663267754204091132816931115040328691632902832840], [10395445062042644390070258687595102512500018933650315707606597715993964482464878612, 38249546802998257145419763086074569409283186547701600807223835513125572430, -123956016182600474470656034235324018512117128863532129371534454070, 4106570681602789034800170279313196897861706204987151354328159280, -73463766422969262486984752407721021045594380722366892138309380], [-9901324210025001866882660925585192061068254533926375777411020698085896865759177652, 31726448624427887257060184080085666309286279043820743164739799594319252820, -49519762357264816494899626136536220309209885001402446377313427430, -5182380014686706683436639973973957497293462710425774498222746280, -43098676106833824055637139468965357804140145765885422679776370], [-9306345040879859364057947037346255120954051955726114910976905727437953998759204708, -5247755515263151240580422859004889207247314346067858153450309372060185279, -202289352650018335878243399155500504583467285864810858599772284207, 10584455647720780974006319941718484386703819627387839845318688480, -14595530248365983828592577348810355760073501679163821037993960], [60965925915950603996804167158272292509191532158772397022491614130590716355324507892, -14575562833458015200114869478647036321297526980816226841017354716757350290, 5899265765034171778691816428266051678771633566170897450092016074, -3600423337179021621234719653700051902644795285312083108726871120, 73906526180399699682067947154342904057738979009557045378587740], [-35991572994406080605285235896892331595863536391097198987489699751263731785559868233, -36330635310716736846266772194122314989768039262545458082916870741319143442, 1051757060324584136222680872109198251769689298467683338665398945391, 95090546258426772961196805254003751207726809152081454836699020900, 46797656745593131183523885376909156964789416091314202542021325], [10845891980134401469084735470077239433744119450838107448515597720934028443887197196, 23611958875805600696765029491572157785566431943405573763654039612961150811, -444822414112638350496649836907923080359202254921401732789551038653, 65807075700327067045997840649562824683727572735865060872269116288, -126936387466188536885229878495844847535494312631407820929317280], [-36450832739322622211756673929008820086232799262435685361931585792439991597306906523, 126671762189397998663705300255598833787114189792327182385184143418285929770, -1522425756963965718772868277702106894252522631453362440328378468355, 53244043969185101206027044391788726325565406739080373170362701420, 170659119201989861280087431223769952526857867056898416508552055], [-25657687997417219081534026487686648833539683353726283341098506348489909216336791580, 79540324854281215472598156813381061624622778598350543213782534239471687564, 620755462403087849703636808485835932861476368485001856292043807446, -357984489165129205963497492040840076441804299502637605814812423960, 3206617576447118520752953226235752928997223461440797972623170], [-233961064620929137338392715604788311548832995858017878733875661932177048455039219777, -34681435209913886939577654511175414478838749269365121467733038001950454834, 1756910478503724987502069274708736649841077678418435446507983970335, -214230504046229930130650800984349758668429469069385639123346132060, 95720014041665936109907136495950237316232809594917444082161245], [-30111441356187697777947290530047164002807163207725521032774063402737225326846368716, 12599146952996021265110522280584914598544722968791279409311459752055283485, 669693644020098794492360288217911003629142950550345142156661115733, 519505594755565324443480463743063981227655931414137698553055472640, 171809519501692678813785042741856741776128683972271671761278720], [-30215302818691144265979368352477428928528802525784090326417616093276874504345721948, 313849210981019884779648557109319126458811471438988051645997135645464180205, -3787250229013989075335406556542294714995312895199710032238077410795, 87380061494863204333063728811582891901825652803710339580512031680, -788193257942717540123739174974554971289196588192415585521843280], [166972161018850423250430239616517986360171010722405930345979801523155302120475979763, -391096019450165044445759231091135622750439959693981435848335571199518685770, -1772733384859995987388073125233632220309436642461938638219532301645, 344437068306254180906706815812738332925097602384155570270657914580, -75158617877872526570533493998444467026866918347824863119470055], [-306205791159172750701396792753139050840265019964060109441986490043129782752641429791, -1363401172164586274006959624824832261262201254341802734909570082017163936846, 2214017187154180014042769956656452106866491653978430855449108567713, 699450130799043504470943519336940349742995368911523180332693766492, 588126155171340048214913690925586847811198050956440015440113635], [293823328788399779733529390948914973195411621186623684552590398107038403791500381192, -474335351507519270766305228134054595014998369711443146216423588163722982388, 5720342439010674198435684225685036434751493211872105274621006513444, -2134197213162711212190855015497620251632014339367764204196660991264, -3650734050745403368228141368618899867885119087822674141057784040], [1404830171522240158016201681296959475113584731477521189369550597630916900509553178932, -592364390015793818642268263058032108140572005987227044134957002049987167546, 17331615556222156341487873151897145273350136620129994181697581204930, -3191605679559930642578748540471510208072354229436963351850298286800, 290646672462568918057629898783319727757830874468182708535511100], [-406573649760767774925783183259818645403336151489305944444922246777914192702476589319, -2749569056559306685636049394614348860717446111787845947089567581928553984110, 6142056640324559013656096122723168991259394001006682584249949030097, 193544209528527420478858313903974396705534618305623984401674993820, 7462709321858865651870621594034316411961544239350512224142901235], [628129931610758976620183856918713926143798111805649190855865602566674781819668158116, 1361213039824217130230445875296467869081296779815316513505860948193882206761, 41822855271221052123463368297434674201344295569517607819167904038337, 257125235138801568024565107302053530704472319612404411306373747968, -748256542005648539226871393551410513485690344679533607287407040], [-1167657689263220536322278237652169699426185914297620400223559024285644606713291893932, 708685163698854749413879191437429058206808515007026976352858429546118540534, 4659387526982989348836206949146363858363493725211104266942907287122, -1137844117653868981780025724453004794034884534181356932958170894160, 3888350360559774478325190753417170461008551384239507217887409820], [-853499841484637223302889810855597502427525332873079500385677648950572405492755300888, 119087194599480351201332840814142536620059185473867952347047935879969898620, -52260420629765231277056331540362783582105873022800764474462006946380, 374282556194703895382013410579354676865313088046260208750896903520, -14781880525135053567058086898583599248226824211264158745755838920], [1698698726877558250071918350880832271105713947727010011881968123934375483123787953581, -3214893935254349850801667209861044217289738814911346811772098091032785512422, 73387977534324988709006967605240160416276984430700955874105312032949, -10150373178883658880732392547220119350428437943043373381943053977460, -191679166967053523702050159251665257259012316740076936936996705], [-5390110340924886128084398559294731956918848478917160452061235853116915255935711685582, 218370749585919734966440940895476076191400318004156342280980595401616702120, 40023309420021157072765084023074816050719021582842076599533476637620, -73628379189961316545574790546991818077555436912571830815663814480, 7224892535560896450697604817469953143251051074749112223173735580], [-9710185525766989401258703410007887732155570966321051682218188489583432752741406351932, -850686142091439765617074947116054971940298086136818516660141840239255745012, 2245779389886905056218318663924454901762588387873213080510298645526, 9237663692733972501949432548340347967248632758005248693536903011304, -3178006826668541087254148350870921771947255119049034161049332990], [-3171395185559168343668913234009102431962859623595898181412266481781738594570746028785, 2933575740739189649978466613256237355998404287281653089300038002923297965166, -139837596572287212792327043136798641627380263766497527865785518840081, -3619171903859728960028583667165527369701724800188090030733048005020, 10916756874382901276418369140178237595799835833324272989101161165], [10507500424206262375791874756557384862253803024635040965620005015449711117663194905700, -1965353407544488677470487929252317055750502072826894732132627482336746468763, 72845043905324744716320556248272415328190888284983912534321739497773, 310818816628438342193959922635434702156082684738156508026682547520, -18873308575840252040155080142317131179228737629866100396709053040], [-33322606879863692903367246525643370095475659166058055938260875502310533745538697655893, 6220540614369657217132361586847608185391576855162365028199578437931943488710, -82308317733408338691828025192223697648748461985062821720068700905221, -8158559712293773356475914213203005513764378279715382887466264586060, -16688089988077945566290487246379899668480476730265365111763018255], [-14211556652299991751667779510919912942945440908266605699246549927372993349665236342814, 37934493259407518457196057938547704088490221629595443378075879470782702804776, 314816198542650306397309093029308187101071415024447817017437900529652, -30235717711554934219144396784130290847423085722733901165017801510992, 41673322828798430885240703306367856911028952734079756878213149020], [23925136961987764258565613573332315697676521352303789782266224415303339374960354880372, 30219251582144073585336522865279011690369658388328086913732023259012127146035, 204264028030398953596864246353601740806459771706715197862117998660035, 50843974766977536292081490190429906120531189005406227555752264995360, 58555071190304852992570124816396544776325943281752486709380614440], [-12319188109548117431091234184944729219951343363496359518617767925970393407734684510697, -81399431236328786744699325480764358869682861131769503197133459415561505436930, 268977422358277935197796491162935779921970485253437857408174461240695, 12845022393428807017274859913124576861866395210253588600947014417220, 50622159461091242227776273580743567828162985451717349430595580005], [-68905428197089510473149912239592798749222281148685735681725574742857592926419921651420, -8277229334328476448170328233603179328995390568722319068843032059326205438306, 19426416850700506462762007941457155139245504668238904225474556044586, -85220298325162513865487769049999115757753764902903306251615827735440, -3236360858839483807355208712064410438947847305718935999286045620], [47738307118921007765074726098047957163245026667795848023590037925809568405875618953068, 43261136987373227723905675891057236767915045846357965744746315024702320012601, -683437454239301167366509005343126759364135809810397831224697090056135, 54715883447564263238366841721757170196505956285554107284235214296480, 231784507107015556918430085125215098007482419710854193780141020040], [-30381697262334895895107988303568149578505074261020193533454171369489989244248214814923, -29064634042121805236638962720259098742518021763848933419581471754716990601158, 632094251866874634583628800126119394312455002323556289548368095763589, 51768646984528415504216713240554506805059660916306752020172208830796, -162145954786528618433829488283122667849655359779773759816769281905], [-109993629703131264457084878534467859996365433693976040136747065746300931982857298791836, -1764326228241619080655743120719654549930012153898965727067484311143490044386, -1379011184337231769024021566421057017822486231225633333435924415489302, -7512668813523641966200351146488366800291916233779755990761882428048, -22678615346638159293234738066224508484698300143820095237022851700], [-122873029442090301180682577412495741770779444998297744099837811343239178554850910519007, -57972871285155064796271409003791136230125605848815491364315334625853012274158, -1491769451733029625758379527438958084930827101734737893873626346042671, 21734922423336907737124179648898586079904413535327155791949916470940, -180543456669952835559541192062151625243358680656393903342423141005], [7408119975672335817459976775463820479955160310093583950088461300209302790262974500914, 6905258918433407960520039104521320672635870866235929154308295324132586898792, -2715179336283915440665342089010747607887513611870733515624301878458604, 161375562204211065107372691197438060118866215019472196798912202426160, -435697983911309760824212495921543937695648961700502689603319978820], [117037962633096382049692164464504322306577737504590780542039563485508248351566116473324, 74347498187659712214421377887208934796340306548772758743797257441914068289599, 2473504598791990490408671881429482068068214283718414849919341174433943, 70027167901785572218354966664284489568009919452361086260557571805632, 252685102988373027477581393422226457085359202983421738345534724400], [-418706000600316853807450550030295620168939050887385796788230446865353493009331584366624, 40882112004236876278137068809287649584831377989913162197868849677444330705992, 738472926739979854304143212211420897992316553879785992799272332370120, 83182278797570338106776072359844143598727996299800678298403823360, -267815462947565636212140942178271644570806887943577577238450150720], [-275324258719372713523606492750571375038777031891776302734970893275766016741733867605943, 855326270155560230844267495391103868786278716701057748354122693957013280612434, 1020550653017192597129172694561325015307502147488091847651798836885425, 450738186890146564120133290487726535215978295789968029392484159057180, -710921284226120211691781807420570035672977766888880335883586469485], [-263191374459080403253935387580105030136706089949714673047219270618061194195418970957882, 440379786328844292066937006739331495117473514384212022476531968681042180398480, 5102089964347959780868690294366548004184199288883494518076576351801480, -588801106645859967017799217449368021018782138894939595222048184325920, 32462026969941974658648761215982743006198494342515318621510663320], [45970885209422696653088281159951152959698201447697349413037694489877864815763933840156, -93557562584714618936350743585946725449811343683690811342745934865016234470675, 345168792523090391465278464193850474059090472752577634140836858971437, 33680583826626107438449959850464259387443712665487128317174377800480, 1881352348972539549788249050256773338814548350310567747134713832040], [-140644527224893527881363102335301385037371425034942741656370382950261658397750511181860, -219574088898199274044578576636068603485804270479430491621200357821937234581102, -4024824785215144847336588471844519390716439536052261320128595789400378, -586931852232927826667231720613948022036011863993892566457676708153200, 1217440114901444746718755884468746187840974274392560083084715238900], [-326967077953637903953282083050112340083398189834746920126467119658162641947725584972564, -1507669137331090910211673011121731049770734586631962378477725732677058009388357, -1289540470714274979863458764728423540112543454628849009485630664109181, 841769448444710401504513708925877278970649145789679631477764020780800, -848189200859923173604606507034934674730978097509590447252620641600], [-379193493287780097195409994960088671759210870735610694151450086871372246896894860829512, -2624658541413474785056912763043132128960810877372166926648916098281005976844740, 6139632743612646883467303892446617866992390284495972385516431832064260, 439415321555704596092364763155377575966191261706614032927713406700960, -399819226908612857540096391727232738388889424772198548192616343160], [-595470118877777996736602048290527303644711470403148882003505716853071333710950462206172, 157953187330211499392167703179286153241730161894189887658372500990928354522198, 339132346991883269508820283856463995435105406379349704013716805617346, -1962159397401186133641519663035564701660167541649027501225696470611216, 1261049211148505618564829934768947436116492492109536222740976202860], [-3249933930786225241390725868722316959905494289205809914217723106627894765896841394028612, -1451574439131532846053500692147605551683003375545333670598308928732178294119372, 6210121843672222172798358027450055737818494343557830479528296644563466, 21019013776939461799563688536432297271872195534586834893386429032344, 611739593496939699169502400177759257111289934803178094419871455070], [-178949199612929255195914673006947216005705707233708543757663841002869943726970326585380, 485806500313606112772095786980919655879004402922206578570597089907975037526732, -34744367536573659178024190510442279673526090985264538976369884474198282, -2607372549683314493672148197679575759131095737661758563713059302621080, 1276179647118938695262787398196550420960737299919026184250874485410], [-2717593812562085545466346383329776594673189492580923301167340111299684154091504821556657, 1626745785149041461192451422154239851695984751101193688345449945440377437336510, -36858455579458938095180270063410582150155164277347292459025995947045865, 3010550140738007733991469012804079539572357985186461928518000669259460, -2730540719664444499898936747896825685980237104031337462143892447035], [1550496645201242581119861732176858194657985426614239495590268459265076638662241085044532, -1570529775212095714065670592760058303981440124461481124541331954612272654196445, -19586014958419650405635193167329411534717882983981982761159794888884941, 273024156616145621030370515048405044466939617459405743429780586275360, 1849861715362196799725222172951366097102156761387999406056167210280], [-4281158745800193693201881020757627064244385120221103634016558770603582211892414734080958, 4464478669303865099148311065768941821437717840103238250754921102712333706660488, 73928816272826202946320539337897682064745463827464371830079420911763236, -7706110185511590545014377909861779810313601706524244214483261892776720, -2483747689518475188290003099909455160775640628769933176852049271060], [-541658439450991492613171871072205148537704140177456393362092908911598286239789348121636, -299151081270723616999235381475302327716028876309801480635635897350324579228414, 29584012153725987588262106541420885603081329734054195626867603150725622, -626965038881567590034248641878296466157890393035760658818088963271280, 2257780816092151454792798719214743835726321157487735329181728747060], [-6641115240455541369242621078307667404828043182632664042448414931600141052052080826007052, 12413792486571108401289047859375441380131951220335476523275167348922499797106485, -72188039497470742957889581587234757701242487711579560419384289630758515, 1264295996995168512226816609311533668108608001611512549141020685170560, 20536539461538985939453313240891148322489488795324074589601309158240], [-4937581510854081005115446324822426449416241813910948328965007094733296304787328237629532, -4424494543522226133753543294409186053310788349482909354819860063895393665566204, 76073403521490535080708981111469436638892046381438856012331725775240370, 10325202290291142450700996046496210585473691445878623426073855577361400, 9215056117049614497511506817453838828644741904652447109422076580950], [2327886464510358868825826832542885324948378499614369921130898842678786058146408754525804, -11910772229209730642193573995052220716302045196788271864664409617350793862406470, -63597890143669117871917465155132439467492957497508980716662483172613922, 5694644856150656514848097484137989294499237240055236337446306439125840, -18165221955020740267825627897672371616719049043271872220674587105180], [3999404324354589137125115655992637675985265364044645214217729724180682760312080623412752, 11824404197753661751144422923705349734087203149135501916006452193066775267017080, -68743061548586284703277030697047224033099515067656486641136239289672920, 8128117774882376218493492488222975724611910445807599325880519197343680, -11312094156943591372003021819720125439998515694681446553771393107280], [20993172744585117076913166393869883763436100423529026856036020768593287556934429113591393, 8685731795354659010571825159342548355667193513095753887020602514916896582806130, 147437385612384205007855085189301505493249871821118309146554814693895681, -3689125714406554584627403331483420805149624509422983304791267671384100, 29349029939464221678121119607895517152719386403677628510264478595075], [-11300897103994389846393662983333909958633695670434305576713858185580481953654893232294596, 16797322972138354046511715955455540925496984792302401628298022552086198939843324, -92002382985828225563035767954976076684230617192958932576471587729615922, 27806177102372549516475202728151701161739565179117596279996666115142152, 85565407340164783297797524083877972121331256133236333823338136768810], [23802063582681104057349379461355560998940245291828445969308604123744745767052215337425691, -8685555005248367307566118048858419989799296954648726828381605716097316543487338, 47186112414778780686989195978130939808249732446130347913073741808694755, -34871147091945048175798788329775488256110922478039966741501442136404460, 36577153528179797875500812969130651991417408589393154469573937173545], [34581763249194741790595492836820089841954711296220481161806860870784627665460856223673692, -22979663078328832773922180041771133471933256845796458541840282157849664259752343, -358060164582409741655484200430423272220330455490432270863088814303704231, -22614456051583211578577880868490901975881718670359743211381547666087584, 28242948496889636902594762651097312492046691390033609033818477227320], [-41055727377560705603411523759714541928033231335660121286910003033134070539471917417832223, 3205956068118075631902809957416424271700520344455712856454718171726859262058690, -187675443950547784629546176934619994485687490770115690067822535093198935, -59474477847949067478698913812714707128703427582982321610708020098040260, 38029882185877548717064385718454082640803438080065600534974696723835], [-17760079114888566516766615310964241342179696515934903484772729031890143126956613186013932, 25581610505119129997721132253182785537054664018882032379818054185960045794282830, -683188853031082905051422736417580679840017864143669265085741519508911670, -52218832463091824702005458255094772909121620283871273515052978565818320, 28560296210015548743056194021635223478968741071795850883784190836220], [5420827533812693110303579069644102904758188064952383509143413087418731198201551618042276, 15213988800188555424571028264282172319669869684528393496095957759065505133619900, -133666862718569312359004581249834421045607476181749403843428523443871698, 99430674557464770953686860029981149599802600817885358303902541503053960, -26086385298876666699405461002371066455578585475565296045440914815670], [15977236108679365014759891566503398928390824996916795535812616685062398641923911843816136, -57723719730167973084813477944148667313747528706426740561167937614350825550393244, -151061939640020778109103311245997095829023162549459849478697478602306148, 80572745063562227072936662607766753772541512003861752946377067342853728, -63556810640219002960243290122619098688112561226015776006963938735240], [43553035012684038106925933374835202099555782467527623489081072567990253121231539485054220, 9654271724048935046567782729441214658919359230801165122785047246786989126262660, -185626778733152975171039546980344149455045232985544556382273025691063310, -34353919187444518631243789203811580752564633814095759972335611025622280, 119455481481164483965558011639051019347860785576450835303608510229270], [69309668879304413700872712585175180779623392325328775920136585563237543975633275191864412, 12399708062779379477100437780549749582442554247963537851959842398922413920047695, 796206933286928576167974167727713791192857335967722870232236423529004695, 19948601626495774027745595670928724025324672964393228393187519451918720, -8264285835698786376028327674636295455726945626615099918797543257120], [16840345146075335120470527573671281086474305630750130241103583803587205477859407576076983, -40017093046675541648403998334975206793415849705106660281694061043849300293137250, 654417907288714803679545895367147973168139469464166390438355280926594375, 76551873653244020764189819890392089077606372062177162269714116714538500, -46047835569184838312638299271513486404047524304014393177951165784875], [74775641975293560071784314054749325006878966577577502735279915323191077193538840445896524, -21407168029219539029150508446839012676855312489237126444874577391984605963361062, -1096224309242335894664405929859009902349327432629889386194075884653583650, -9262200583600575944036767609469762927561807791906777446703447888434480, 143911488916798189661657865175783087372056651238597816741312779563460], [33810363809806312778648619733705055027898635719011198537536511187945987125115807157335373, -82605395910617621439329216083243814848071161717203884009615278835727715822969622, -1292642447479665443113603916525517762709571020269579909678646334896272739, -179890441237359727291400838814321481428457772542784956205436307877444116, 63124276986636949027112081655420131051803126788475371978459058201815], [-255109074268324837863739248104230519873910044078738086939726983721782088994922958745141600, -161082591861010193301363134450253014381032750780156127752269966127283918166710128, 1650520544685228377735140855237362913716694310690722880854687706093045488, 45310778314119645511120263881492607793618948598789131803163636870238080, 337276767427562587957773181283306397060957817794084526289910847551840], [47934477604776049826722810559959232570763853122589077602859754062331571338757342768793148, 123336883091289326654904175935342023933734957686917881149774117824907453214524895, -3263409473530016294701816643069848071226888448198702062010871169411746105, -17007557940232488914908103047080165835275944079965841606193011631726080, 326187282075563509063074297234371589504365401390454013730436264919680], [352932432457953022785861173310050204122074354288210018449189161361680762683674232501187277, 25796238754187504518783763602536979419738589058636135061001714935389764641906746, 607273176031346418445142206821472163702715971500715330499888012385270213, 150661731304663724287828575715373778013897755070733330346209845934790220, 375667555549692882897177830746300832568403455380726807192009793865935], [-86738448577996076593183245926175725099173028850486868416144138629113285884434943119464868, -163851786395006869285340184614632182689435501078440538428980186207713786864125500, -1359636132569450070168988625992478082249341518169472089281595882783522286, 315688957890513394792492313772696025001740397945513072305953037947625080, 621121729667113002584448854418049762439161869305856238735422340361590], [410219545026018907038560135357928162366856197903919697139116511060085602543575306647993272, -193063021416131744697970059085085096297377401256126047286563216548372807977436212, -1710969762091647700839339121521821719617869058110785636505029835716533804, -17170293625263081693833533452569691490366935151084477375584159716008800, -390825545851213203096703412929067368047856024798567263604114741737400], [364454397916850545158494340877781821626723937591529817639430600154902914058956384053857091, -186190720123951056061163232743524787735833384731022316207305382304028018099467194, 3663528245053996432280237550512216366205723501552563987062210519644084987, 430468224749286702533666672221214638675435311967311992859667209180922548, -138939467348340213638851652143009314358930971863083175677126133523855], [42413135992526932793449475232549672156390107829443528354050209195561193063272074663626949, 40996703490472566213507503042004174230310365544010110319972697651352703617098586, -6103677323539839328694481475831164484150210214288367276170166912745221483, 1017208105768155771933113678656837311376871424636337786746276520187182860, -198131919345459765038356960980916168109182239108992036508318854145345], [-61792942935112056807732716391719471949042461787661788617099831305199953981112774588409580, -193307413773750931540313286797920486442148590667382237774811197411221664539107031, 3427266511133455154240812625106861814157503696390711941749284390753110641, -898536071713406035362387515892890530634521458272596728981662146135062080, -116198499772698101904996448195452879621486419937487154951477005893840], [711677373577130056623129446253384583472868414006249684881164009359738264136617706677467342, 273166742672975432256013370250585776898993459275505509713191971270031114688876152, -282114214651707610426829388470296216682056846297667151310442845723688356, -941889512749950269691537036523552684091833736634789275988565758148811504, -953754987790803896574022041339774038605583484700252188841191880845420], [783628037898936390532658876923052280512390491560492466240944136029798193762685490755246848, -1173409744268664858436471046781760383933730996884223945856149836851996887905213600, 7084379743645439362496127860227967507937158381805504606959217747327122400, -1436772822010280301451458592423364224575122095482727031279043338187993600, 1993367362547398573004301683705788054470006428321268407274003293833600], [892128713185552765781298660320314758370334246071688763018192555869355451068710846305862378, 2651706655722474688851375877769016560651829718254292744726764724694519323261842032, -6200583886878021392460333153665487528485048555846735738913714115302631816, -1430151555574421176573958079595364160839227023281863738940296492795718880, 1257677598241749897045174837866226307359882442120377952273358799494760], [-36934406996453725307706652320127592298280367596647860098504257192693637566037879237957564, 838975949152634042859586662885816141662859611449507617875880807272312020394935717, 3548457364251264865026919012806675141122000537941635972746299747878076365, 3736468637946218363691948833736985208384191884992591363134825316888145600, 1632179974959681087197814516009417588516656991577501733954882179858800], [553740701300748277253082291706271028808436069707878523644200281950949972968734423555907932, -136450069667008861326329130003262305765420206430933165719787334402854441267560875, 10594464142562082581711502620812495925955926300130282634555766313147051125, 4103644970419375529332941757006990254979803474437210685954041688329220000, 5489349625656289857124678380943977980559644044784783298246879051861000], [-1770894319497290432023030147323948555315053503843711888973348226259059313001813533515540537, -632935250468805646573989926029520492277067745774440737441612452858546253624586130, 25894374814876669624091445538241134569833521878033938809360961863633416495, -511852998365104741018309189719067044958103709244273630287180561049165980, 413051198356313778358387253711934641174572735566437375898918041352205], [170420791004259033184866954948012066695171040972213931390770333301708656265179922384754220, 1143271127723663100296490164281330016152689231499449888675355548888920140720745223, -27168667660761849664392792115925149889794562463064300509655339374163740993, 1876926758793417806448524731373485605789277764852172986178715425121478720, 735673251060378312563988763395872933921844163085788927235736608884560], [-529797064402609305471109597843728522871683724766903988594297243124287013965764336245801492, -5919510656832738159602959824777654911229836922955794486749265447725848608822847516, 3096390082880413111438846684380944119391405466561385192190699215250903202, 69941216540943453820601824193800012635989894399929066947196566767225400, 9387894662847087681447458878016597873385467359342990335419316246662950], [-2410620834424658068339844461648485526732062034475011780184947344026558608307677278078749278, 6834959525780145987637359028975611286203611858033109845473353344037453190102764640, -3335428367256054101503930581407220369856235003903585817592594707303489360, -440011241228915577591342812124949547677937912743246473843363247866810560, 10126956717553767549693284736924619605169921501521807762214162774559760], [-4461317037806596158007202992605014675400231346533994123597843925456293144134091963493259931, 1494521841426277762213884279408066110776126053617880316940402111428640159403048538, 4405170479129751623623279000599516957738373898348226235502068959050406165, 8457704254148613564688683832140726718185102587679009001332467258310393100, -8936129507161698524498579951094143309505548120169629885253001526181825], [-309071026642912726655122578708661598061603426146540443873504519234320506383786145966349154, 5851152693992986967142918674752650965889553009619363104042947659686030472428811584, -7990242242859883168955851994307537369518056180143180054929108329084939872, -756343361204998077686139671453624011175405351021498158444289111143148160, -2532294427286683337879504651522790817115419749716248135564714477819680], [-7011456770313966491984735664136425525733047262881055805960635542071065832731025855631875980, -5785951876191135368722722350627286208949036445911388265098961749905911415041584354, -63588009851193501776930362985043917965791217650579655265181076061987161926, 265324190421940630142555749041671738002508301965862291263112010313634480, -12436692039628729830791116672522681092795962917440316293538120775583460], [7409716703841550457775764007924868953194736469802487750709253364992837299767088272387055723, 441129031928572204706552734721808766343035735703730860670188619634255961616420518, 47623773570600229015225034848285940131437669369160210325446523574078277611, -13557784488532364959709423372319208800346634546018627246734546569853734156, 1614077471457035344440619540249216716456459094224337688200561786088385], [1710131500012604233424636463576141462058930968394561716259700951047629632796143599661344952, 4306625840871310784504928359546572218014634521622543010912172211071169882972348660, 30105451419896165784940737470773970887567538655959895509304048124207157660, -11105388025208407498244959886007990662703028254311923887235801308211612640, 1129290607034835137397627082039248520969915564579916322854933128342440], [13393209838545304196730971721942747862387614356974375286799278261911793520506161503332046905, -11056925581856941950267794674980586969809070790153649050598646422349995733892947038, 57322339840498719702293856492937374347674005147144655620676395831551660633, -18446261836576689749615841301756467757831422606722691902268507587297174660, 694052423962398354011772038721509533697718857870899377657012589245195], [-16249014184180821362441505947248236171975373962223537786518473515473188035770150770163288670, -8036722237351482269577465668473684258138466224458267938568309892426457184538928640, 80300006430162815437206070046053701455570426334878908536673784739682319360, -8508845116959426480375927588541965821307432543941863605746591546979645440, 21968183192173978106275002643026787575206859892364023876611074270538240], [1692548498029011075202847940547584198819528147949362074507452658629352402783274470221946236, -6549398708575480104626079964006341324810908267772925412720676985756694253926577219, -187787390154279870467538369007928168733252390638642033384080026380729764323, -13173964242272523982231759568904174740745428746928340607964447357196658272, 19163780436187814322190844220970876066528317593895708384730421964417160], [-29457640003838311300556165308228395252574880066048250097037176563384012097592954584907763457, -41985139071984750907516433527493344405783763111285641488639925027612995552570608514, 121242095212384296461270699260724101854378428244998275682580157519779531255, 31133434913273708064775311015277782332185998608835932481318326816190691140, 40854942994379259275269059181496505360696655156116199363319806614399845], [-11759320176669637831668593561750497261464955297273150857776402645395488274163716694823459328, -20903102939463847429992804977424477487656999541981693317637315310284494020491123648, 4883161835450903810444210992489365235493358474139800977470372773480835904, -42979529933580863668126599305578112285266658630362566266323429839011011584, 8266275162222211581871988948854349984028980382926845112412315539447040], [1277218518131319602535602305206001292499741381087521328298982616914187419875475544951492364, 4559202043976546508202305679290912721384624837734890539711997914588803336919499855, -168292520013697540577794649032653597127256864442607508265378293724192774777, -47353730993165039543355105033373322509313906402802741199735052000331568320, -54962564592371570204877375763948282430440586123911340802925431360645360], [-54090138655235747807529602043215261601718524805456593440077293318396962797595831117351901036, 16737459795550918795387515142540429471361974017615354402947723771048738817948689044, -132184873336876791020597143949946430154925533087832630205105945122010984902, -57237810563918284404895756015924225012177557846056967891476184059285689128, 100696612665579042509185291460679070745988398769351659026687296420644590], [-38602311785141337358949020057806801255156744512615150958453052274849477661340734119694412588, -15518150207013544757227649610662411138104024621029636337765347160642730788919356725, 270012514243051327774192899938378993189189441106369609038712175154022885275, 58278888852884811225137938861840937803491296350323701460977926660216698400, 14908543053855553258058406015023097026390688405807646859717393441154600], [-38201172825618389803801933040917771418512618476639601051106865438226926112148870035015622212, 26392588472099179591684010937318543520870498071102782459221881468397265260901966780, 44756771434466857704844370350112419211184793128806037619164393924714361646, -47388033329175503422902090019545280357685216704558518888070790177756870520, 98457798149802590541165553607201344491009106916383377333526222403305290], [-39598563867848912396578848870564447185386409558776532064438183908344899994295570336577687157, -27128209715454558785607855412095785928937248129673717665336582158613686103645033610, 131374432400000730182174608578730475625403186540472683391928731520476290515, 46172083853150547678832740303843146188034023244083022025689520192005369940, -58059780681914375168732602521536466585471164355036350900010930403652615], [26781181454889473142054664849070307745146570638969228839566164865371937568322283883331942228, 64191753963378023642987019456068960677079820345172828146993234117821178395832739542, 392644210594606619090720587868861956764683280920113677045951411951304497074, 24994110577457455070357180371531209186583464669871630719759996352818850480, -46604452268446435148592863870273350574188622454098153849177540058335460], [-9689829303533707592149241143010502654354258448289773646674373844327064202162717056464323876, 31669298297436893024141195178158416203668626164195011268488063496819714100857040897, 909102285646406484977850026953949042714981795466460589003507490524308510161, 71392219140639053776452220728775853453669128091235929374977733211215757280, -104532723277033889020055540012858993315853091227835348591852221847931560], [-22711832516038593015883125504441272924554653162534611729901331817654654145984696276222037068, 62702012703116422653595208335405219811943224888605533373250984399650578445597623782, 1038130824350440643299008130826567879252453155235931366139636069623903496674, -37572973308847072323368603640618601568331921069941716328867222857409686224, -66804011432869531905053986735322967844700298145094168936617445712540100], [13802848097246537489059631302074530476173002816998423359546706844155626992587977019753845182, 33113932456469340376526615800533975641878414102426602997617826013420307685254939800, 734210809502136413972500446450636547360613028458099969998793528542512376300, 29867401094466961251461545387639112657815660086894066725983958169817838800, -64055167741739639581492117635943312362667942083811806319997277444090300], [-18510333727892527104078344799135837969601251919817630713826399226948283823899654587117665848, 44681944869583691396364442943259140314721896886520935549043045671986332545797233164, -900037070898848260255116155197701699671904122271765555495498350399190118940, 100255505906065518976921461045628945920346070348462741587317310166922972640, -177708136083493904661378232174943833958639125990452613610812330458026280], [81559385241671028282809836068596938492526422439524018575354094339775585398932294533818749748, -114251974982240836658735923227471396465436580111835280072655451888495683960828920220, -74898483666179047032975930741506644254616791334525188042221279600606605470, -258854987656066249392262308878396061820037988062161713982725159862176210120, 81428818009939439032690860068776813153904477877108612875718221820359270], [124093045846105707150482119804607342732432050263901593609292785796508287821281296046229425356, 10329608121496703580734472664644069450359966344117370940989294011543662645531950874, 530072077923340462481894640127519929299204566094270860000188622462369465758, 68028407075617583091751513133609315815352292696873457942921314352049472720, -380374606559992401344920140560998274919970048348834722742558239026410940], [53620998648139060586378182747555592975407984489933198868824121868595296589602195424220568615, 177830469469834619400535716670342841348260686532195429040658998859691358809507962926, -2239324194801727114975600005494514891300922173284165371819838705307356345841, -71229353851488364593429877840841492205007152529265607428652591527357714460, 82710695958517772311503662227345446755221814313940720195032463240976045], [91173164936108506824460103017394142911191317772275650067992806847860332740918679923285406437, -57198123961308825642509700173098785183606590217009482054392506113324346877945143670, 5645302377504238857352587151051161719913215085897084705851112645121714284205, 2750776513880362905742419500324324224743791212613170043570956368056011180, 151267725685107923221798432583150968645901328108230648858098926245545095], [126934064532987088026857632659085331488693468636123590019980849065943214544181505651914299060, 572344687776916318134556267334299606946141973556857285520999107708255873682425845710, -194370426121694721491712686421884984002736076605903742221053693900609351830, -82958353165859782430472939379507661150489609621683345274927383423337322320, 806868455990217642299655328283443137766385643955874764279855041526508700], [-421017397146669525382360875997215899064916291283816744237545222975003183805562195941694946324, 400643799154795528987947960034881210883802623485751984638463087830808941327154565396, -1376747343146158932736361767508495227670944235457354740060047974353009018118, -22286266590873075389792092142835859911909973180546717105754756321230234152, -793197768450426824219410425767472461301310816355159551932909406931060690], [707035700624702406912485213748947454182660025263282080695562877803691475898057909350111780920, -700789284281710646514580781300321286546943246839129321471243334683932445754374580636, -339483511332620001385707614369700869319796342747066997205062149212174279604, 291687697460618477110139938711743386364501033486087085009261149078982743840, -367138625510460092763153791171017697414954377101624940928282220548758680], [768793453895802837068373885517446927303463031072112663589698427990706837022218253943995630228, -601351975163143983136463019712183575924557936009281569653694664391314656804292056949, -2039064443141032640360500719877252161871008182251864167952968737452813224165, 848060229503596080044885327716388931610156169627467560286722575551187193120, -1583559214471443372791189381487022946993229789867262103045585262123049240], [-70881489641293997821987326385345119909044812656974641710763905108860359255325532333396745783, -526001279022906615859901780049071607417371037206048915736999465594769058786222369918, -2267403528405802522888654291932267346116057064323802078967460264175473733431, -301987093007706004082735722018833576647222815763739685425347340014369289284, -1674420619680545063596891040605242594174032426046436829227826928240925605], [183043688107791792038757301361263383970175442633280670622772873732601896340010183833457952964, -1251012272715742049021649769119182218147956664021731423989650455921446457272425595180, -6031917841024379872635805197353071093368148291963648622902520958208961048742, 66242803908586295072129006975235998682048237127810089830557966156729029720, 38902971307115906472293567369511570388089747848966555935376866407071310], [31527383613331234606462254079218538247848206274995766398328272004751848761056456307383283344, 213502489168662547178651852689889667200701567530376435644531725065236538128072147864, 3697496620607342656008806493292922945819716240463668134828665821073049102408, -43615676101173904997395322588791480070061472620807995303663774536123326528, 1735306930070882954501861820530736494034000565001040104279210796400157360], [96105987041193675117382353486700308652378817427942611277843240262815443818155985931041452188, -5442409623116124603560999614154845330826587334189305202413148269055425960810370790, -9500912749626878187011322470869237024848864913507139804419446359785192935634, 349765114909250475344959222230509267858012501418581244555726162767552703760, 348630050953231544032662366632209103247209040293393078265719100453400980], [1286944070172406355268184281441329823888176214226727149890365730787622869199946893091656573028, 210623987312345477463311117370557843957574511264179398088086664990484288693909151485, -9230232478562536477318455155261909368930459861858083965797984683973044535515, 468160637244451451258515785868715024127808446674484862732564558413318106560, 1167897096851163848232588593505835277024608467407051031359911336193416240], [598843375981773277552073005151355002730834606115758591094420868339509181158906375443280751753, 141725554303178953880795189573534841734349407041162248989978989047900981277302360402, -13350206039433918085730709713974296694493117561605677071077553418263121704911, -924102824882132478402874703665745732766332017640836594643535200145679557860, -1406107253531579847861264803849310228851916470084489327151464090863623405], [-781443334097570381835529455042939768989718729176769015258631874313811565232896871152273008996, 720196421195515498471202510524545536010364656524184008655763698019550892076243431869, 16384428709050626847907624112698021636066672825109248115052087227737850545853, -81493837601960662465913307493387824127585921106085288046428972924233676768, -341064269486359466287121636553612811167847311984111921333432659844737880], [-226436651845195396811408442328776913932996803020484399757852063427487892612225347340445224928, 207408690123697078225202780215827731546141152401327006378299643469968305359197946480, 2536896070240344260234093255573074945318503200227095004912956251622665238480, -232113125046266972891590648470065655361701466827034867286700666559195809920, -259772896140994327139121630929950202093659142198135948593029006238315680], [387215668015708236705663118379549074342760781569266286470734149897499377451856857633380424348, 586029002825909215673024899274524702110994505805836186557663714591037222062564111940, -2022155717672879286577067842527928069383200433807792302416087342766240891310, -1522903860344876293439097922885223506248217068787312899048377131983599450760, -6047486775477343128695360612194225575181621951906649137617405384327161290], [-1542533600026229369162705535696665796143388311601545911829053940308545043498196345064164512564, -493945650088367631976481741597969429328677186326761941770238139844978763212329257525, -1823848247496494914739276021497322900774696347990418097078415113086459291853, 1145878988778082717261748154592654402040827917605430787861008753801720803200, 2833359259671220356062002321331573949773132327273505550236610330977333600], [-1476988304014193170572313802905766844398629589612041337284881379866625016992989256662627590680, -3410583905008704618829668422924195988905158924614745115115671031808740175617973053812, 3894897691923532566663945776345225479199802765721094743955710688059828172292, 4831288410495449489052854152542778404045479691176443970292435683479796772960, 337618200632221529590810887385495297603025929481690168856923560910425080], [-395081141570418473302957146523644575175922515248330806948583259928015432198865610656780498164, 143031841498282845999213783171636581401532824397529203110519550513207034167445058076, 11883445724742915259406415569390884230146307976836252181735168767687363988702, 2976485133943640100932597924787362988592133828005614047719480269211625124808, -1243476276954798863293900121613452730721830241649836385108848676198853030], [-6944076860273693774245640138721765195794727320987707506461902366727744219864508293018608837, 4017850031879940279327225908644070062786919063053494412582929548424604842490287018774, -13277054292569133101270125403494204214840734496193897293189106119372595577053, 852372263284718605817316678074349525264008337445550390762486165102279031060, 5908411110990981990384907073757272073464620840907147994272447580311254505], [3218523956062757425570166677608897547213809660480538800831247563279448063014368206499756788300, -1273215149257932166509978963817956439229071133960398343984250755348109977345873268175, 7413331589972027791612538231723470780517003973484766741957498257185459450225, -3484122030088391030941165149097928082198942045134185825315859855234319804000, -4518902899107580203752795132427198116816675624117247436833340679185831800], [-3412769936843265546445133537749017643103556379744626658954390797164220974299086008598755094732, -1380928201982440157330789428607668923747459557352241563422211924888728120652954273930, 612492582229891247609659805530231714214385990792816895740515203757233035570, -4003748584760991237530728360843964805102875755173617443116885947135669027280, -7262882562683655264753330558381200196810766712536150582125484954765183620], [3791003257370747635704590806935074316064561933698867135510746450269345930283232468518575153900, 1140681257149503778712542508760658921436011745569728932071924470352991676424102909411, 36206864589332914759350470261199736973916248953492197060518327974570818553419, 8574905055676564545136581377880544659957315490727189357545187335855427840640, 10398766660697140808829812485601634551985986939723881170003131349174482720], [-4902392476909233290614948895096149811240565037962488049930684325002355874498997886322582745388, 7940211621343548820226158382362969344056122113366023632564191837501918626626629756855, -5891512604580681458464499422098427399638921620084371552952617563018257027145, 4032966517719499390965875643328783736731118228923515228401547589140028714080, -9837544745055980234824523318529987391057976733913825752640201367923132680], [3538014513273572701193063054965913988972278722882618650673872246270069721043094555118590291692, 6516340726522006490339816191949564694991456421287769873775850128728407534768083609906, 9888980457464437077524138698255557842445451484858908722164453275533732850358, -8357009800075597331929980979787774803267040596099579003042299860054543962160, -2782293667140697040831883222960896771127202603459283607815170385062749180], [-6592765775823981600803444569752376955014163529472728071508597563273303094299343837921665259235, -211214560340563364461625855346982016837478141873530594501110734898604685410269311990, 54237128174959860179474444079841599208957249034062915444758531379836342725805, -6710779348974066796821030989506613541188467684442327664109416144266041660500, 16266556583390418918929037268295594993853545919640341599647055887461955335], [5704344903391055666497985995041397758399977971833703055792533381269949398166604625959389722502, 7378240924717298542236909055047186644138638432808368358071166558853550782567269829968, -53317592254692383033841139126305818234269930902756869540869988652777313449624, 5293243108653651922674459653351160845904222027274256050425721371125539125600, 12208580551121667690829756450285205546538089726955254775104101291397503800], [-9133256002489016855235426590345658209612356957050937207207714878919997155002495007240833544884, -5580568124980185195972233039631727263150370018569531382822014773328415053431101302614, 42919614022401994804234883832182192160577993412396060479700522647819522260462, -5465934586683559100302358600901951763251903599173950973969591142743208554032, 279105493475134520342313207482896016048322201371038334282378629254819460], [8833628384227985753877263988541603704279328280931294312140741220292869239048192072202741495104, 5458190262516177001254189835760656807368815149143824428064637787289363283982538860136, -30604639324231404467028087598770556888528778292372234436593145817793226981048, -873434542970798762132031295491396405721464777253562954487451513107694696320, -11910800441829595430325169524656867718794281742922794274093281467363179360], [-1157488488564194191245864250426768450754897800282462275609023639347837720224074148181074792172, 8889292491711329857854209596388521091009999392126808650281802811925359299463073905495, 136161998413258865233102086284956266148320921614576646408993886871433038793495, -4783221763156155544853595967528629875360619710105143709608333573220562360480, -18910976959119054694240044101300344651027137199257736382244293214671790920], [-3972715960125209943664127871353341016468118321464634969353666133134874049878976513027668140788, 7559166820144094220464826749544075804026252750904021094903765425988693646411516027587, -37515175117190892519453973292991999037891532338754335728461612342976926178741, -8502866862423933581043918444113756918567964214342625183399696559404652771584, 11831840811276861986178673464383730994995004252034011109986950636212241600], [-15425933158934380422292005076275565507662971693186792467572830534701289044248161633867617258376, -2668809661972771977187824285242256215946470739155633100781101135147630994442182185420, 126357907973330822574674766310850855119571492334294331693994763510456448883868, -4628742326990297454375992696343990821940089519482724555801279518514041517280, -17730845823934648456160547711918167480579245965760397909513380330481388440], [-12582160951484397421378660489183964711669111598164958390036804462205437756228501782688434298127, -8769957689302708724297687638935941153301998303687360501657206132231964273874669744990, 250623263455796861784417271237041569338445535544265510449485866536048267035161, 4689181008071437897006288879273527597763891356423280901838927338975598399100, 37144310017170333302949146801912840196391624112982761856952863455016873675], [4927218450486261400328996766250132553119123984211783153447335953905747924933523412119489035798, -27583018998746998395222730921232424563058055453595676765779208230916340482344592783600, -29626729992818726306943529788572191698103733124239887428053155706564524956600, 15231952679791140270555487672697720053215661156283822339362333734558873938400, 28150184700756252520965596940536024878656040179100613825636682797511344600], [1896687116888190179442829178527917625107197470219276614647631607389073636876811020426712370004, 11572016394661860308194492193686605453595401062204291998242291488832479390792054161022, 269411278256319680949927424848381491598582561433766236008831666507799996100346, -5394794667234286863150646462875042836679746696529625796743888843061123086800, -8043085977463628726159952518137393167178712167000279101042208748586528900], [14422943999533567169763577636722513342097002442044615817595231510233787285126439943061261190284, -27145197412140479904426383318566708939768207814928138612939040694979173422092544604756, -3061392830722512908338508913688613324797531308000462445676177629903762990362, -32634167624561907418969391381685663353226932695959702012769548443146850325848, 25911428132736912374473751742461084336543044033763859821059334495618006130], [-20067707395881497826812714169801491646973557147182975258033471319742675743261854017367042088609, 23736580683610000921237160407602376948757729800619478581580016157569286352014214851422, 239314516140279700881399505920865943166342254545437381589620559442848920085095, -19864664069651185732681961170691039556102284310392167412877348842432183192700, -1237644068142520285306225957945629680150917196649299172308987333974246475], [19810099917711693388264046465506747060533180962480274582675147652350819145361784138433959031452, -33349146022702703707081445653020309045347890127646359134238446585225112060856422889333, -505122044333014602534048182275746912623487003880199729190589818738931483361661, 29788236802194698385980692291389847796255192981794870987056842636971418076096, 11421318389334242162045600644092742507796146124962470910826447407759462320], [-606562423410859140959890871059682153413547393358693274971655021879513934165687102294378031763, -1545366753870572103617754940141189856719973203278600803700056770511284711893914570790, 140194612282093612162404698663447523276268366986321747719982657764329500200085, -40772932859790359267895590539560374223439067594640495641149534038248085572340, 22592636824577331534500552757068285025450911872441443698062740451586238015], [-46506029994498969964748862323267960607928734721363623444815262972656779799414672776805487776068, -5727943089034321992706783093659057861466066511764153554412332526551725239840892699041, -26176175093005863229170474384031278712362735270907363287078655484479542407225, 54765252992406108539038369397652323980095585195162310561917391390610162222080, -12147120516753226122828471218398746327019713571387577152440502802379836160], [-3462807522642020869935421930396490361308759045410632659851062627708258461773754357421483856625, -11902465913096901182812382243768700541006420768327248362476747009985726908804220086482, 177098423832226271203809309326715196311427411850816379916035300847386532640847, -26850830455711417503359714860573308585207789440999007364327602681846172781340, 109107781818291450745906247317304607959292755973176491883763026211047661805], [-7410567508914480100967993110869243780480436631154006234593544449744687678303439898363823530114, 13661135973439152544935097725884073485809933502934698190928257658619411811163887976568, -890774227714654526416601153115013563709663220747129165679419734083278573729956, -70824470333004811029488966746531611676579631654389187436899619301207907151600, 46359869990623936765860028119988256405770982277018519249305606684549975700], [42496728952769823284433621377298752808967829723710214888523499188329518589072849770709707620224, -37687003843327750777512846768017216100764224396297936312617558202463553188029322146272, -69513426534693240787496000720461333434022653120381746972172249547189541686240, 1058185377831119688087213265656639586275901726403496847603757376985062108160, 93114587813550263594379008084948998526750572315358942688575461537064359680], [-37889918556896746859939497033470325411716998621006756230063145420686521176069671432327734951684, 57314132083853188496026872770109447176993106705683137306986508038859235946937987030159, 589877205646937717322610044946458483279208659933085560275903080047183980093943, -109318969750258520334156095832699635792028680604593441450950184054890297044480, 104095161708743944838372880397613926908180443096790858629003297620795960960], [-57877615186625263781015178000453729568706298155209070628943175815536442616787097330211363208007, 26037143163256278219031333561616780044987847306817319063267521681193900677504871328578, -1136940115464298537027423003111412007396618784583722491580135629988610109616599, 59718815956762239904552278441573703198286410698702744964647735370039492386364, -103766767999980895724488092216708687551906083188672633776367810908418663045], [32708899406115228347836578355152884044732970179038071298055146325860936937327581296531731749857, 68610811509600584675955381895246255770324660232363462276627033976475568020792912630146, 208247276989361107362947431129183394199812295666797845263281880913744833995273, 106088607980962174042812688755013226527068369949843334575620782489704810750140, 66666734120687392940063084176953565397705373983714025546115050558470525595], [-57990663127449191371933417629800942846663593097952771190032495988144736096750953322622200675028, 47140645331130435311003130952266253855637612587037907196152000758258161058442860379860, -621825587274915126722720308958572624534890565266307997804214815088274923267366, -99698735463477601469665278835623377319851215606226107490181625952441820057000, -215417189467749080090987246169598184203795289838840943484876638778322867250], [37925286625874284495121657091554307209056254618539895131899719122215562445172378103971929205340, -8593946021750774538256719575545155126294835849130161322984831151630101429493625594775, -1024468764253939999031510416969303326021281537772706058000717923194134052713895, -11423726687844260951226553422735191800894779089553332863861567167424338311840, 28615136147922306295310131444210272307541815292736335351787149386680769080], [123430601229580749618139678506599381503505456852503538789547469889341926060430708873511440389311, -58374077077517835052932492495429181752296656331773263941379647472263641005692465962914, 833798103161842321917021815078783857022281042383575676956651286051931177265127, -86636369890176304038710245730290410005451584172130722985614127760246699760252, -19376493670235255586545437691204354263574458893004274179357260987338300875], [184396653883678999397717786089861626256980780664345440885282881296421098483297971802021746196788, 115635181820612506005506534944696655164055638968895584848559578992651664467418116745140, -481325914770332121295533502571794969453725027085356309797941247125107892765110, 27540224034362856751796275109028191176748082263996506194168805769445801292440, 321321496653351830768099849730880164351237180142515270898510420572789940510], [-78010620398077068369780974364121508195234484976841894820638801290025821777021331966810528678020, -113373355132390266681232869628339432252624331427886056506720996278816157945427555249321, 330474952056956318284496782208880769704875897609215090087599749368070408960351, 81894164609165404749059627557544112834003870920489068515957706513997240206720, 412921332199222737506927889871890688218811705053039426659762015225723278560], [225620526020028615386570219647862692287282740675971640624746046512454566863282178257721972432439, -159086378440926053273790363130371860816466533850994133214485440703204429110431809884450, 1303417897738146588879953692148295669937475600690828206932034626188711858969703, -89296595593784676452377475913668287822879371177192468236571408823079612658300, 79719386717538360145733305102156595807411023679295356804585100777233564725], [177961372396543903959251533964924626539051042958993394131346346776560719052588251020270244224357, 194138172359689872597582914394185119452975516113942793721797183459526812980715011730490, -323299522623115650492507733347259176062757162524341909254220518405284589808635, -24466608558839558018330736005722362591887089135257785929037106018022240225460, -743314573374271206744764747380561293270803086259753929504717854822515796465], [23488561962260366197539322142202217841935648138173178471490725364713990332181837081740582471548, 248052368684437485688338645076010516891424268696963165113195457146238122507966653115365, 2180516462141917174025695843750786155774744052976218397813793662688766347857381, -598642273432282534574870367609178887586348102055516296832929423119290103978720, -72712972126485832790491568920265750756878873256455122757438447354310689560], [13737358965697864948983066383742575807607942366617555406631237718185233444855022919418198436628, 341188660662830893479503615208560913805342411193507037253325576298563103871639966755772, -4376478647227542951231976668264287252204017336524042829574955149361625324231506, 29485717701361586074877825500590114376539000703387214114187848231804204097160, -22999401079914937654285230938027643565261321076792815779517409056359542070], [-23446946836673263070089873078851828235093906450750561099286658179599856618512128799903616793616, -68040034738198790832377734663729407583187312274953032022725972886642533922872484679816, 3857608745948754305377823764893027396951561179246297128547065679898583919364488, 799545970338469779263085918883458571313663250831801774307755228235473824341312, -297469791634067235934092830329909408469708228931058759092385702319785292400], [-6475756763244952668802254726974135790877413802803837809242092095691552408724242113654802456358, -386054389376135359289871278585767309344848559597233994078620501860622790959943246315216, -4671900478970755558463271382389646114995985046505514114115236189411651449834280, 46039467315180542389881575648086327408843750564778606003956371364063082261920, 310965853707349323575068513495666214882785295875540660372656194029038113160], [528049692388583273002223479771091173647535736418980503573995490636304413955418674218157921674676, 93179298216367032278739379722691774878330675706351810501767104602376570434061787288750, 1417465748802528086126419784824648173869146411415429120206546790166632766349002, 470499594073101677239632961533933973392769185499714993553992044832176721514160, -935673463544361861548830045648486756796605665749790068658557663103516494820], [495678119590600221180699248067633386991368480095297324720276644231309400638640447623646856390060, 120797302096906685860456324617141977309710112586312806874298320773908735814867211482633, -2660407260635629016268058973839009409345330227206293551954377896118101854357623, 500303230173473309929694957366054947786924208546760006370142761669703863681440, -693699620865426462920008210519055615330613552452170560010890695034322453880], [82952950192248736448929866711681410615441554936679472921850354264722497537739629151020303987381, -746017532019744786980477586595826560167896352223479690024464750672674528591170417053254, 2211271628445407635107236077063517148258661256484946577622958946977943226696517, -73701242806902952434828977549503099253874263529855030111259464290684567198132, -1662550125382253091754522095781854281712674636285635462426200686904247513905], [300734055251674552764318180379627461490075127134651181048838515113316050096843714724661135144812, 691204201528656670628084976025758903246767201577566067953884685118413322544054040544620, 4425166660819237992688331797356332535288034318899867224184995265626138957564870, 1064345482560894577207110494401650551638427619961936953354673049579978933492520, -1379322566520195475048819288804016433593405177779703214813399065704486034670], [-316030670521164437400919547277086372323705689653505577873443405012014931660230386408746169230892, -1710390880501557699155990191451492701912222598135770009747980681563406416238304044231125, -1843944980225183553027245452112803428910266135601144626478759485994232274709125, 387320948697449103722449100453065186343284329942023904582042882656887274196000, -625926930851325944158631677580666181168781780431400439145996579171662055000], [10811916892424608592919552661401167719776720331186965467103153279952932243668399945379934468960, 165902089929630670273633103977497186879357024395305603117180295903073867961881650246936, -9094388089653291384081787016803065665238249508578375042470125719710463647540136, 71671724403771794309626851006840343847392553281641808514464891258681311175680, 288726821136755164667903172401982874841762840061909173090979329446491536640], [-1384729559736828135101899343231815181157313035581747379031708870380624035144695787950681449371908, 687484588327524759889021463066639147499507869226151742503696140094050348387017707250490, -9338096356259107951996618524403904205088623978565813013645223676693205651805010, -218505838397983759358842888693311560909706890258847546144437335166978411246960, 726077863832048802975847125096336909229405696229450838494481991040666604660], [1586255647682397121133588375767898874851109359607147504319598083237160824726539353747020425693772, -71925219097658423102344274082299411814182355599210460594861903887266700395290331564670, -389235958920865170829509800403781406345432467486927097719330834244290180826586, -1196151465209854004381516979179364844096486042595498683572859692948709953052080, -2678049904377906157820918495135739111520731996428601486257824591308166341340], [2109589146486879321313033553346824699364081808208753921595372647832714791192914482539210724966557, -2416362655194206561202824491406681793652504794193563049562691610451417130018795877322470, -6748823550433804214492560974845706493728463535730817693220170052515046940619595, 240013991244720286909887401967390037603220193817567522829934022472860122506380, -793759905303294890774790617513288652414973868664165957060664023710145579105], [-33107344886203009195268495450785195503937346517391358498624849302018259250535961305251962815876, 719414194525322161027387692806309232566000594108731345077426155897252279275491151835211, -1546620743599873808908747493656875425687725367148275824060314049428276644055133, 2608686293922300519507698405868689553440647279820330522230699721444599298186560, 582929986376317323399415955705262066116532228268143225963958262629245332880], [876073169274293243509572173983477513820196156272311527761238573784001233877599404475645034492408, 921452094949756637919760430450607059842055963085034000156229847186738156099023803690380, 9074462676471412472772333245771569949338593787151124270945604021065471216487380, -1749847993586597508776039614934528264576439477220958977628489207201100882215520, -3356544050508038686623002164231622666771485050422479435594771179919497833080], [-902643508916974284240827456230012903839721477246088572797071968601447924483995362821639117147140, -2263491353574866831860822434640782111533475797283401383814605577270938512942015394750276, -9537831717088171325333514616163980564973245085446682403782790616310579011249234, -3240327462043668343963755424089161935621343871895951253412602841563727044901240, 423970110230213915223911281838767734962141976991347339853928616426815894730], [2365754279315225948593863334313997575684446462654030263488649711196254082721219865733945529807503, -1017605300576528805959764241115386093915620460863808812544560053861571451405242752265714, 12942061663979916789065088538717083675450763454320717772044053821294648389590975, -3209454538379530234378064914440819766971178653942003499628822329630023409779420, -1956928194303819674059498943062064723335386982045683453884589408885636100035], [1037452156119866248227502944821886615359020114151295924818125464519898638922872949136184223794692, -537479858190132069350313473096803797993480147126468672105721296462091229841324433200698, -23100536504547397112378049116001261738370511267752451029755059399718970558751406, -975713642694981001398630129886462945476652688946944072377636948672045026383504, 2155877342038021649533732714842132711179333492927291184012751627757196835980], [1077317298138588795456085167117177891106608956134937054866442045220359344411017885168079576485174, -114741919738523815335074790315064474693921757470915687836619101385435806301805411763696, -25447103255616843337086638161028972126645939527029859971680084990974125892101432, -1692238965230305863737174234537150398067033444423849717834994834422783615727648, -691111817789474113629742372319479770119946047347830138782967944550815342760], [-1426681339295740407395711913337690468785580839366929755192430295409549280045217007738987253287097, 499034255724282308822139988587909444166879618379933837747196913590712879063484166461710, -13569649281702306493255517981960890202672000340293859585619254448527384564865665, -2071085408811639011005395636977412301865389587820237284387292076433354614501340, -2647058655146975398421228344958973623163021832726414422855077017241609055235], [-5515617391558783928743595979779403202826713906717940165233231169120879823778417377312848367583436, -431420077350959712899272457383227074582111395843177121397854723947529402451196236798093, 41909907944625779621898991947439739960223498356678554276239772038595667303272131, -2088859109745733080326895189790193993820609959048187488717760648865625772300000, -7237914867076503885638895402425678767220144665631143857600716511927725375000], [-3585601512130038109876982455431218743419555937361765189995671360219883854298401442843848933947244, 2356232880128013415768915656044838935139754191195677974091443362501390111415501399132532, -22477043647196685279152614958857992619836544994924319185460692321677363948580310, -2467264159275802826798054007065355939613659329490735328558230434966628258511080, 3101880797767283713730758368563851290621431241272624893933021592695057822910], [-5704480292297424344206152369800820089811687417285648940351789887956075426909601701112803270422292, 2838145542593218410431935368111790068999318430979470148889886218200219529933130737563285, -28059012519692080536115105915988986775439638317812524192801962699553064229214715, 4507885824660724594810007967980172927787922464402303531878890808921697104027360, 8006213279370346575030140557651855595314207887623479207198033931684695996440], [1588249474066845134692312937962976064968685545187288613205686860102292500003150441301149954622121, 3482144257510310092858632972116165506546988363576804150139535093492315125510618097632850, -1666556615017251641906797687278013637905607371926510376944186667773386462626383, 6830810759349590532034702059289520775137597852278040561133425301559624836525340, -4914554091459311466977516660920911199279474449091279042758086731892781149805], [-6646510726107483743494847554077071016980910339055731585277629415367439980716726285976804605917565, 849827642701812847659543743947903109007982740139388601325541949435380635260992464078550, 43446525339411776779868017930365605540921645549693533968099242483849092962720195, -2886652445313106064678446222280177846658678207991882865633304237608184588740460, 13810521882287508724287081088025617544262623673204214659054948536444784329545], [-654666136546701249038075033470759242284364805218868656186243113811406811919410168140647507365248, -5465459257043539432817603228513078773431303155631863708168483345673833324282950734028600, 127188372012989902568122088929419263346101349949828545342057543211461525880407400, 2655033952907590472185428723295360115660781395160094206980251940385619919766400, 11936638114816213264525263344848102083504981633344478527085159665632969173600], [-52132421218555044952666638743048089265439702740905554225307328884938015768685082618049056473405, 2378638100869021977278567120925976658661452581722810962105513354401643392039123239562246, 71346544001658294035412329370946700179221138234559730444989307991344687099297499, -19166163761895047275172498733939156103759707842446645609761127588731169956028620, -4131871761270314933660356842290332689782226937486038440622979771815100209135], [1084751661204047603603954162778606641245105059740822343949065324775464924372375536880878524892108, -10988461688322045903693343009108395758408232231505550597458772620178518014575931705070887, -114339175475907113824243460281238552852601734767532256965874994547655520374571719, -18386193679052664246408943854798143053464402816923515306138210514114418932903136, -3089482658471891041141584348703569308446568684561093976823433724243764273560], [12138544829379089493575610083424162357528188536933378841271742353892029722479146302846324926635980, 3383859514302237850561060371315108958039399501354926359084772056699366157627161356609137, -178289196263947745276253859944704321540134510157030855351444820887378013354338767, -12106567622947052774676462239560416457548603348598724657140922058291472999230560, 4662989269784881052814474224673344750235354840486847936266625616714221050120], [-14574999400146589673791142806594798673506060678802971030526500272247173452174707914310422941432578, -1404962250950578741201887576531387670782115029754399354031780043375443447157825159544104, 87151829336908470304530492195366006347562478756038112389331144459975719992124428, 11268784817084815129588339381392560056366007554738665668271148096464018202450000, 12051682015709003979980849907957122046958402576608696371392954797961914382500], [-14440577462507147507331261816565242781740982152032899992998160424674826754539030936592856309506373, -564887512170061723051288768725074737817678324845664804549414280823566774577574930445690, -21913602079341074487563621785001151905195868456138741094531466517016359397084581, 25477442540161372453359237278683158535970341242727400663655124381671434480231220, -9386233099393739381312923623674561606132324640227808751083196071301238104815], [-3818630562748455868084892462089706342414326980668277020089589440417421294803047949681628257912120, -1846214662723592651169458290741177807635656065783885023484509511742608705002658780287340, 69809143693775760631449251409575162125030468763618597602552261374718291398136460, -1085647950631239461760522993378495505823298437944118856477698944333285638011040, 29999406073772990045951751750152624790325827627587848013067426280161837741240], [4260622139046601977655188219287896320446771115616421992054556575319398851369313613743864538521772, -10259157774704868340343081975020136388789533148456088200007104275892307828807840827278197, 326760586122699054494312133158447614878164527656782973400075319843743141509883731, -7322523524330276202399672800508361072042613829538176522065799623860294959855360, 12199141896229745300021595812635020115366725911000544068775249242497131814720], [961840705084344850978841037275902435864144071448411491398023208368371212170835226804539151010772, 9405143920297375616340288040218505281246181210005238377082649875578344040149304201886735, 124382503787924180088770272320320569185241010920049159522134309295276524072122735, 3180526345184212260262784537900652893069154102384238449337199673437726197646560, -15713824997134733618965333781936053266987438093064588551935058759568837574760], [18991722771182854220735026562020019169041896262439626275008085057686095838976831724623234074900164, 14751413400736623705302919096090213947207012653226142723202821896685029624277569646968396, -113528923964326355690946295834399872184981745787634475242156808893967219692072138, 15171009975936325652791093389444423289353472237024066452796868943401371244997480, -23735535113138772528898705704062608803313621811116170582020300648241169015710], [-6906271627109921128783281662951566197368852695464931929617448313543218761189715301670390749893172, 43745000387270667762331543426483736777862736237547927363337329109202839096663808632863581, 164426419324829045281838079542563082524137508110818646025921674349857521417302605, 14513607306234861731693215378646994241880325401524691218463355411143732790712800, -9809108371885111495086648894944737177085462019333454070304307201653630210600], [-22113414925477078470762305254791650463183579884906370914617970253902363279083923597176611088657203, 1929514897742651202427957514787024517408184469219237081612106963503059744018373191261802, 23101173328247131322293278817485279131518516939107981950721734643548710810824029, 3654124712726985018897857734390628385356784821519981314867806671061100907348716, -48406892064906510590151388337329063315750416077185853658396526700904848906985], [7500997572776508363409902456941512123406804005022480844914851222276149363122268857807888922454204, -17619482551753415477540024792481004297268420816912687867680704368109394866489597866117326, 272372260959102867297017198574591654618301556956630487151343540330657543842948678, -9919816453882549551531628663846686460072024620989097199982423093845842682507248, -23556901319052437159179528297973859937743003254355325426003957572990170490540], [7397557524350195056826287211017057582062697713352513311303582084677788235228604597766231436918033, -18759720436043157223110219199593997140804079963332156888260773349763435967722136392020398, -10191236057113751191718923973542613311490080842251319063252786934853812104132751, 27685178221863610233404926655859912289872009159853262020531965347194855032261660, -89252782657299588088937080698006855354147539911888963947573452345573365910445], [33323138888214973277342783504679046270865319695811932428084802602212745686270399071823990266999896, 1649362946655755534999173804481772950869827228985141453726286695613414229826519061365852, -464111765876130669217564950062558082796725878951551673605428145605235066285098300, 300439629874364604743438790498417616760728975195731093379385621342908932256800, 30094981938946244464019808087035363930434633715160960466666089917864714431400], [10649765360170228533900519490314884662489514929123021175242638877332596416142221109255961635964907, -18018204268667488287841640276470159561828882895835189958400023196300374823690147774854218, 79260820108487803933671134212067363629686607130253042123407112036755294314784499, 16257335753677230504480541373541507003670977414392221230040579827533478725150676, 44803464872145453599647822344795658482924624186955564476279647945879995963225], [-10994428335295263042718018732935699752245798507922214160355237858167834243237780367262920964057412, -49335958752730242898154981514720618352678263505908611597185105775844880804366800694655180, 354869247741635853405193519285329147167236287896262123699838757537716024350066570, 21496483737916237511433526149630913947243135686533323728243683630836492626829720, -24039763321208035576958521476327752127738746236332773408823756996665183246370], [-26531809352719280824906061870474033540922564706533317998434273118614599678726366827075099742319604, -1421313910539455860238501252902628723433657448989112780954211645273844424075894308430615, -338913962888115858604125652402102246988445116506916525775013678446429897927455543, -8923940097762507278686782992764953936054049137057949975965789862602691677183200, 30666421093498563085834392896800542318958764871905794958662806310942241911400], [-141305352184368513009376548978999727154188141417022205940941650270953179286298983067304674112460, -8071203665022469718684014053064158593954970674922179911118411037639288094457294708353242, 421346927678133587691020535382726086801224477846420227369692264699234712767321762, 33552507847230735100865292589921953889614144401840247703930153604295696689363760, 28247095083242257068345253648746346517775633656211172024673353852354929345980], [51484237131574027819368400350864800555306049024045504203269910671379274974622621263790641353999196, 3518782003623900266417337284687805291887326429876370511907644947660192292132489737303756, 204152317870360356335335959747464004133704192856058507990384790924120910228530422, 56815815451405196662817223926792983776351140384886914721247004704405638406334568, 122853497599473038777210161343619632655160808886536858206130603142720632122530], [-50723520591657877997153657248596692553278228643600293629139566637013717331452421864896372177807060, 44393654482607174991511664653473743252343963564262183440989946688157567261769685172962195, 809872897967258766032685275682713238462957958712678906846308569314958378100021755, 18094434549739917833818809476717335256505490095475190705324990979668037098893440, -94693596196724809307535358716349733238503446671293595558826748509535296964960], [-24782726954105939934506233540564841915050978825588310316632996846506083775939696810290380054948992, 58550493287789890829299042642355651653727414702180249316813030502080183605239593332721200, -278078587933561307146745132924779256777630675101616598228412137969792227813350800, -27434705348220995648590894273090315319469119221542269698309346929119008788588800, 108997879146621426753811411346657670648235981065218452392394195954181900228800], [-21133250162047422964118681439730064545582896563741137540134010327350899301363555626494501107951166, -82322889722912337294293853014547643275445816187917375052688065114045963265269805672566272, -415181128204395615858400319413234211670323301437327550448762230970590393559473920, -81963577549070432215064063269350871126545257713212491140128858783206479572608000, 10121662198357516850290175264492841432034725267571051210457955684942660576000], [34712042677314788027165963443274475576906510870590433469803714433415411759014021668671738699102718, 15473095069052986398239112729482906588620879910456012949292795526415252693073087782212768, -618457334945002406649453573393540575452369914080674736989761821107419221828760624, 160603391120609202092385902323299683884877840214294453686013894648554729897529024, 279996095894615154852114846867325057750718830875960293611803110483959612434800], [117815021109483275197115954452095587915865824458694426382501637083704734308443604300769920856803092, 82507794349339682831953016757576372146996074185321023209591622414043041544317963015010965, -1466899410611447275354145005103530211092039686876885517191975350783692284276450035, -44100420551834946270013298662676353854774316143117033279315833276072842846607360, 90541235016188554844411303387800606275926208409327588090443911033478497026560], [-12650657515476661684934335137127640816717113571413194785777532842630157094617376734055590316552690, 24364074985830351334625131331620780636368951109868499501497666439908160849642019519305752, 852185391168974636970799919629270446623698338480029147356692354715186465921491628, 191741319454332441994564342099582310550769708764229930078444383016285645733544400, -29962596007767529344651226181242966850808649520950112540137782943747555026300], [63240168161521691645659776085581841876192078169212890767607418563020392872198171497446460893383983, -69837524244124165518971561002380682581665583929659666988361757715548907541923064686255010, 893754927890485053187687271634021226908395001499612116071479353100965523780704615, 59969798997207955032337562181360395270303039798907252144942386474894159692401540, -182989772116329652591233872301290457601137428984788060290901059577340941104715], [80527869331643203597926573944574889896671372673498651961418512811740672283579322844059935855710832, -143121032132404576656443729974064433592512448544918219693698203011290593289114784439802024, 913774620394266454142065615003417735295352347014079601468395671557055765194795368, -13510674189052157001135298360269259574548622775048293728818215868827737198745280, -128162800397099801711060313470577269378476665626994469016363809389619209667440], [135619038863360201460950272930441151058356460875438823008394238226343922363492536452209377637211682, 14354659492670642182205423119039345243364356503926224210298890501053335082620825562632488, -1749413037401984697479593707124265986948118636503507259212270340161390520182851084, -145441282415492600627563895162450844467009647077608473749716444613492909913108560, 73965348928781152349250672962032893567151252935117908159568425408705888438620], [44684497823704315132646363537280817333645596179530921786913150039833719713697525337643294149817612, 23050194658878653490420018272666751348449566201999380689018678650172478126023799851422940, -1328176689521687988040191909434333012035751566721625528316407613106056814663407810, -156826345892499511820852798320425441225928379661060176580853230079681915556024760, 57580026242758522831298588830572038741373258097333375244494827552008939385210], [-64310227094258658871891815235012641320040524006512462015460703009759375480272063432496994643003548, 5878486164061542314214261726525955277907172070629300222095374275703486727425226360681777, 139709208041026215208825331362760248496856382284206138536009895863660510862155689, -133234737480696515045363581975370768192764227194957642829170425137504017788366464, -475020957851406703027827145550374176347787803215177858739593197102589090720800], [114639410286338116491239019177747614600425485259550052337167146976956725894688780715880534458228548, 161578532307467469157845997384908222027287469941618898107879754175734093167097883853300767, 4753061910229970892989745157036880612645265138895754514096577608062321563288355439, 300361217006295830529133688344037731271796130087728776480361974741876193666816160, 20019347670911746448418795799200740855957794898658416794666162173418102948680], [38618511848714413931032372748955087670607582232326878674370105902143213380583329799534303587812384, -60808189213582073011080088697432796466641117843166935806872032540829943422045257671618888, -2627450280026763941853901896900079032811239753850350729969967119520662144264189384, 388199946718880673751391752139527046489638569889631890696309336479887816530632960, -499074749570857696088267751957417762965601435575431595859314287333918473609920], [-54223835223858616027146371789954417269778848722224024819213417104584240869303398039204618681035909, -73833922146113700650940193444710692974111135747621346806874273426317935835554310714255818, -221275444839723093329298528991227821760068614868506060616231348981412451344479565, 297746418284589932835916391417103084870739551917739946003838835523599931407951060, 6221454781723271995706625926231066076161894366198183503825862448214406084505], [252485421912256790059511461530484142834662910702304544377680599529684882509078361068545671216666117, -325281586751845525757638904137843741565651025417525215397694796582018535727375409317746630, 176111438451628727105551467260014154908214862882116300524536669020548460486442245, 184615037523639561258444385470348238395660992256382740310558853084481202617011020, -877930537679814536183030345254830071885794571437910901891454830666652382818545], [-411178568052821871800886838131404832803503651438171870473535661788896254470363838704653670526777625, -51592776582873512981847271654351190230372145801117426534152477530682410800903723285421202, 626938751954840702888717410020323412436526436835296051267034622229630359100469167, -374149719074486122352439420785025473227075608558122711602753003166338321668924060, -569085143931077059205335053437213627737730149515972721255733435370923939504755], [36954285407033040071106339940922877170733228827877552787967889106258847452401177015395529826664576, 14105441469750866018480607825334607791585254011135452883404103107544460394576689764223856, 5958690471290746209218911769329918592458472458100288047757191385917925470824730032, -110725409993375427284551000916115625866859556528919666656733993682161885244819712, -113626923559242455219006040960296451377964348695052025504538985184923297840960], [341711570122297424469272496713566836668190866817413697317901533093209890398019491881161094494329348, -834110834149226153683275498993960017959668114656148029476269466714433562908769505747270481, -608938562405182295936644417976964309041500014193129483987011938586526231924151553, -468935033505807988944606053247490222292040610139641291664894399984131716396797280, 765293262235153462621026443837941344241922260865582157504296424312787882351560], [-591216423960026562516075220163804155191871558694171549265685811663970615748784036347086667808882068, -531036303880410500925104235947286418970076462324303357185823296975268359414919720086960565, 1746443334724766334938417441644532702483184831679432272806055703756680711510900435, 213074586046118172516657585607895776538674733379202088596734077802188845278965760, 510729793204872269466059788733560019627188296277869120540671688238655433047040], [-164432301960204305707375285572825934767327125962251621465793091898333244670195079552161954358835644, 487398879756624730218006559245143330889943510197721468676420296099138187435588188277821569, -4327375968521665056102786658800798021901292128529400510841713259252070885397469287, 383223742350782949817771592361690914140132091329474925358241853963664457675799040, 6143565582383990706626970047172439956518748319929928900556101244128903585920], [53507119324110103447110227655376931297602809796673372658794500611512501339391638251809579400113353, -726384462670775946801754181712056447872552647559064137590469121211100527754036357016864142, 38897752232420792855978318045992612327058443640255324599992900361021855410749121, 667645671604629647711686563401031683990110783395233985833087839121694437794978524, -964314426762358582211943826779592453023123328546531496456292466391626628186685], [388948209803939953904751330572484533415649712205169210417266107757406737995506489964570610882188630, -385987051438428942556032063706474442034209158445694698232522680640815657623204153972857904, 4666053787300806343429815568865382964459442698619008428338887324542995305913899944, 1004254750271305241641667716684185712324067176634429180310919308013692759707111520, -1307233529759326402708125166503549985851684765357533202861211485610353393196040], [254153803755984847945595568238054436028473604354089569657247006647841393943131106254052311109719252, 244919196377955256595875200374444076216810676407070185129853141952650918020068830339448860, 2029390660541385907915243063654277265684758746716615366462693797896286877498934110, -472579498440772232030780142189269188800170797370667937737143372946402158937168440, -1865247690760588685301584648226241073482602281862458412012904162638940743369510], [1267201271560370315510752343394668533452844006913402980939584466518791661744170355291880820719981400, -645566661497580938588111503310066292762925392435427300483750750101258255575804515249129188, -2434860613738506920033086734098499591756864152673831008961259650828736359281750652, -653196697903340225698601657663254342036781703012316175793694177334630703647808480, -107321054218181077995103653276721004448245872651272008517205318836415172606040], [-866254201548787323279451949766842192254371044905861821568421290314197286634386396203585980486443643, -825573909326566244783360102693591639062865947145081618473190426778822153563130245711565014, -1233544284572484346385248745072560928362218626902784846157850875568190502880395267, 592346202529871537937697844577072664996018329917729523261751770864848381161180780, -1005828689196992630270034052951095802575623211682860622064848476393883059394185], [-157306977135605935414234414552005417668796041243235158174057605608477988112850261900725788012826638, -22816658546564214346697304013608398511718466154931970449197731024432860074489295915518680, 11344633315916882301934351528924589811876242382521143728815584582112154192070914804, -489547957825373367480562978948801455497602222318723153232047710552619930319027280, 851381728570636256787389220204515500454271276966135424548403010225384596884060], [684080749681091029788002004920733736831878069635026972464614889156318962539209310693672927219858591, 1493752937278377873333518994176164982640006057739016071938308230958876099715202689298279886, 576469984509012383309446222937257102825115641084995855936136497738832857213856287, 482347519611876211712375170622516013966547501296140371647511296060243389868200868, -854633854967046090320679109723704740088692788472751770536604365924268376887715], [1346637788373659703669107784915604292550030280692056086025718705038488889281745270858226809212144172, 472332801481297514137131139369461935008859545066207855714612929546325764754403239823057010, 8345102632182576382840817859320439468559096078340996444552870250482951688658739510, -320520230166540790637607414785265007296373800423617889479115085659809344708789040, 1709026556100225655757500421580818433369882197166053554709535125031894731702340], [486892848200731300341565097912972453735850112338050275748300521780378717678551639722753951283371539, 42918206114359602783065182577573360548890151369119808813733232434318359419722226360000310, -18234239869373390867963555720516388617664527512483819193395006002376645905727670157, -129198733642470740617205135400292492950081702009065091042741730023927162192080940, -570574156806389024444432530179132062015712633410292807131109362715946484131495], [443820574660916199446315281117768417942274310822254714178027708247855222670138402845722443456982604, 157027330595683794976782912222525813211389871235090665316072572001226322177102391700929319, 12021344555937680627927962860293519652741011326376546338508147314566925187299074303, 172108231001517619984310114923649751752725255119641700977474986393808439764490432, 431586500239156800939810571882014575639233633151443313985044131054535200103920], [27382646387282407536008325232429111406603503224544346450612688556862520386623514844611595908743037, 1464422519930824439814560272665465603657093106595813582832502228717213203857361393073988250, 14925484086624222754527101009461163392965356097461063419504471286723486313814699125, -40005131545736420357696967043624498673781567138029225013191491468419411364432500, 1263963144842623978294540193531643509014843388089164101882158456460030592561375], [-1945421073765123622924819160468080316323773282744661410660546594365659945473249262657846126750565452, 1560674618327056289523524994451146225067090330411160125382839303334618482384770281492387635, 6913302348831319307011695867236003499242670487639910916102566001172648466128939011, 1146595440805215565306814086479038109765004016632579425203784672746449331530880800, -2363251266812961860150209103166791807167270825926784907318591331250589694696600], [-1255196184418104994221490433504979536832554046350294621524121573404673356818821743566799868441947912, 656515087472822044998275782197363098140031782448715120816368580020501731604252126762910580, 9499284455124177336989165053039154400948521371490101568894340264388156051925471580, -11981290581365944715618347202355666741609777446821675053356705299588403392708320, 3592903169347938085133488739941373099565993000202537531709115407417986380447720], [-206075678256262560160109031109895262293514052539989897774202166929058053749678323853687784037215421, 151452790798449236252720427012302577880168712791974231347620317418198121639421165213974022, -374096669169546991702827206821068671029526692897573663205153942061525597287854629, -2172707295366912728540893579303619164621009766734451884011353264689923319085239500, -3281797298005665894895536751264012676295973650822768862476665046270119997595375], [269220477877707436898261498736104522180439359095657727825862236689669521559298911657432079980853012, 128271876412656997721652243666661968673635790954674565724956110404093357460012528497192385, -24197384068167170493985392895288955625643265971168821388674313421501629469603806615, 1413016640110657048995248980107331021410599764267799519024572271146494577615888960, -851968186833760091336058010095585139678207246099497043556684388027119156570160], [-241187991298123674634673763074990335980934520288113761867744633437925440700623338467399262849260898, -600612207094914981554316061666283399981018885806874220087322700494116433432275562137001576, -2931690187479625394384531112318188522395995256754270322668666895837285110912862100, -527869851252384344978594260702468020333932304900875706247425471752812673078506800, 4582899749897394596497569348373578122573379555864431244296840869050210963356100], [-1316298485638277438562311745970433117975804078479871079314360554422398253336133665815478334980189157, -1061570617778394462269049885577884640117451629349727694974986339448575383287029561375488570, 4463758567636467023537975241389266288385956192819624942147655141661634842816930555, 5183817385571272789881599088678043482986907364450724938166591871381206462816025780, 95687119595522171389587694136913649411668471069788147339457491969362427349745], [-683347925087479469951319637268645064297003392690697723226075380329022583531598185172230070982464584, 1259987560495027891596798697683996796034002688968184403895277235974917701736078502179081620, -16283358602354669883877996888728728573628748887280348081342220579117485826682475588, 2786088462463730529555598669771007324074645517100487355320547848142790668123422240, 7049956363348507757794054712700241818965827884335779768856472370708679000084520], [4784495619997283917214395372837079947267657718559629756796122901669326511825064563741876756372968861, 2449161348910268740890865395309648022932296406703764184997125228563101987216080237587913466, 2006354278120299866011193942498641029341275984337316364946867298643903750899450277, -278459526207479783305203345861266030587863613187097600328698510384898795542964532, 1855620942554489609489050418318183786853862202322550719894867410735981291484015], [-2319493926478503500528690853797635150910121008829563654641349571035684795663649730348519889358471572, -363226713178904752152525581607832756030407088099661977411273171271361633774780700168845756, -5433335954610483930754527701425583253761685940125115889717069871771769013023398318, -6694851042989058734067856072321524972597928771344057643486606231332869944443329160, 2274896321260785921388245525750277986758035546141868742361362529740413650326070], [-1620428108114090357721159799832300460779425656206672336479607081034093709933662909049841173877478000, -1785931192872215836366433199300952659248515809077647177120497158516835599488154915360742040, -6531689869625322654281638941053817730712441233205822566016706950888205522678911400, -4518252470564800133601060573367525759669728869427741913001265443242819521134372160, -6810739756851868734207652609623489998534457439689700521183688444921725618194320], [-519235621421277932416363600091269505757793159295841096214965879956630467407340140873878855326573852, -1941372549833545537155741588341754499502193557841055122859672939374837893590350483624265395, 38782115604986573021396641581536340673816473521772147437880348445427719517479351605, 4716154939488850422064386253278785121951803263133948659327626811492189317192550080, 1899679429054916409613830703159222499414315511676697169014159859675736534974320], [-1750625435683349253182677651360460096397310197855309023144181349426578028094091302662720575232789724, -1353087050703084691975569443749672953670246906576480079166395262611104348005243736885630396, -37505428922325673601386406760465090936043698465184031992951858659120950954885505582, 4469581965535086977822454070286225039014105589030217118683673866192284560504431480, -7019435198578243700824808305002235439796898665206518116203615353978648016091210], [5082510741069753851472027015168623000010610773482604522583570498715708452269234291571740956816495580, 5696708863149160969751581954847313658543536478494823595721557446393797359358240623035667986, 36075347716275717857959108443324931922051536895347176946637347931012468150807677254, 2162456107522605075091630430414263976914176401238021546991507323614048638004207760, 1288592900631382955090311788043531286091941776089954586489708365839717825492980], [-5066738150360544323647049097727897677907999275550843771436035732951190264954390882177202039626867095, -5846811031244323664686110481804677772804678417382907606962666168515799779081137088038717598, -17040129914120940256395395947051991217386681816429257407743284742042774744145448007, 2702161634415321127062084038159190399052136349261344470758583104241071080035126780, -1444587423237597086871877988450648273980465186876536179406612245036930684873685], [3966778620272749715102051413228649802167064110482592043063959328911088318474271849835072927934483988, 3339263267975347815272898842545002452930510933217802769170148896210070259309021902069118100, 2929477295142818593888123249583043929142075116023447662878181950005965946458497850, -1001747298215817294973594012959867005208633825224547883156192986147694060671215400, 6075428513669218735965710152646503758776596329781691735524068716800096184135150], [3802997087538705376423365207419977253808262307956766449639145616541303913860544546972292395977278232, -6390130056549036673666290619330002419590847350853600319015304201054667948807521625292233220, 3458017931935643466567268304773283680857068670413322444461054850277167447098744484, -3203660711758986180858416103405296816234785530008777200164620067745934418765846240, 9584783029465639741866119339105610450014774687472126379518065688933456117973480], [2019904223579974203326094941761269000021843630282088197662737295967931648576332485905735699805885876, -2247945943956537459544734232506349983826666508767981549661209978591265928833355520460903759, 73468184734422304741469006510543149145116805243064608625503726651759009453086636857, -6639679908838110277650185613624150110314787836508695780730122294108045230123281472, -3071825292845091290686635140983629304069814029304836012080449327051513909939280], [5906326254880560844093046195303686489038411971422596183953824759221447465361071632986435725038120804, -5167213291085241733004814406680702163622062358692874371643598377199605094415847912311261159, -9577324579172036525442366215928954348744716077252410960327695259684165087465143503, -1817690426784294951941872199555457685083290523321246852627607417928806898221213440, 92019088931106308756773028049128120877554463968617109592773038126197192962880], [-3881168267002843794838946783945171849213115845893572178728085595321203092489581130374894451544890700, -12235124167545876317029300080124727156612646402691994593077238097310263568365632888151109156, -14675506823810583962590324684926170494957597092008592256514086930685611075092308674, -1267122288379296934052245187553636894064908602331624711552378294275259271658450360, 178234590935489907643768667793220653531455004574625942986485603769155140750970], [-3387822765822767247566221212576691374625494445133100894566477785181468718824650336169049655212469077, 4620900800374273729265549405816573382230287680543473824439016323481183481542248278064312806, -121960509877180604485720513808391236346297041587114803608109175283441477083563583605, -1847377121507819661291278531854746939288056302042613906755215062433550104690292620, 5857785595426990736528900608035352198545700845221660513769056684673533104968865], [-8001407720068217286841453749923879747758662023950249372649180707510267621045645567141258877879978452, -16536786606617227281716471592024918685811672004747580423934485498684726647154543946568414238, 38696581758739571482245582847032590231860307224565759789780907457056762647936341094, 6613246858568189081717903772318744657658324853434524323838524165216522406917257680, -13118624392070140111257804563610391562794520111533560652980009485223928051924860], [6918137254285041778366032022031937657280959013286097217334011438554950117738663521518937776486388142, 2593987459750634781673850576257884977179705122417055346057603105740721774674941339931234520, -134674341492250658804299673706625663262226328666152955198281009410935806444046196980, 10105367854334907024736326332567110375482866346864474196511732330452016423853091920, 42599801875299546436809588612897720728085237765958454867393322167417970653430180], [-21847348243574961944078753444215010474404739596912798742947223164909357534531065714236027494350179772, 774666666225506629263870576072966302378409447502857885572098881881525334535387153060431175, -143359733751357116802365520070087802822278997299998447393875397945827714931517434825, 3509199935166817933977550143384352719838165634470184576278217903839936723490080800, -3614919683386336972430598260287657192608440236097959697628444750354962912979800], [256273192096487667673477341193761923262675560533855128158193595872838497946309409857002932959302836, 25625727119474956695859659218131900110657352851672376052992966272088601647781843081659408931, -34406987160866307206015836230528531856920013394730995360906315945367593612636151373, -999028337007078946247342097658312176607178957033964147632865394613337407234146272, -34472652534346689723543199106038328568506458166706787930686329166760436222596440], [13624137120638458325627994138608420305089701666565644850480018274715749388721346378391329150018225928, 1848889502421066465903138893720461267674812564579677037701235137110318970630556351080941284, 13553201463950161721888706210678095396920891390308629777877909086914042112039353692, -3019685942504504579016616911010274965345964342244582883926779657092316070993628320, 38792528820790006473259379308096169382965297288518047685554303959339125178739640], [6884898771315931736280307364237970726328368718988665004669034425827857813036311219348078698960071175, 7675012644116542100032607723153395078209611711778183561325340941115994364313882980490275870, -154240499968356453487136517026181168784276804816466817383158826953035620527987464825, -30216913006364565062255731593804258073096102148240405965052800126974466316101037820, 8396314925468153500265307757931321048768944735313118557897462891884541518081685], [979603061305527815126583970019324565851360963489455171765971067334132552847548523776118397925278772, -5126298172116350810846862091086956120377107198388914853962067199723961985569083655981617810, 173268834730422469107577748894605998289669291919133175140591154880196925118037159690, -25609078423349292744438946300261697482212543589076325323186443162838532761840167760, 11187673791827948705378523459174449232854468650808718413309789376546817877570460], [8526991437359410723685046177250963104135983587229572753160914841308553082226033026502873264359749321, 8697486376997809313254619012529933473095311999823744457533051792354000276778306576695047218, 17662251709440739939997739590140523620094320003704289648484774507666597466371267489, 23553952582720100572797747402172567619745570742610461136650849946253250275338261340, 7406532565270771943266879270834429703931931123539240134068521934038090233028195], [-17487133571077316758054121831126299524915225717783163495311656366588292174123703616115808692629135972, -3320838440456527471702471405809329923042401150366282832557639273279642336411120999418264357, -212132808302135741944881786929482763530292158271597944333875966418506414148764744429, -8107473406688796338956559498377360646175317969572504550385937284866262232183331136, 55822432728426265876452980897018311541194530719453272664185489983278036877502320], [17080310869096486741724063409013836096169164428997258591858241411303263690767671780934962336603573248, 26330495826413348475814952843473079073057666507939409516789793903858321894715191233226205720, 224479687830881171762868611528616620031238762579970641470507433757518097710856505720, -39731793460772854230841436781276745746924298779057921661445939881830684320356394880, 23885770484725694217016150610855425529926742502466102876989299516232497193912480], [-11861502146153691315466127148193167760291371789967771481720709558518645924186090467457914686166193278, -3528260793149293455103745618769490641395887578472564334691947121793207255085522499963321664, -143037511388735144647456934470266782065106713035050812519314890236945805344383678112, 15843232826052438157710610002372694608661538761563603203177307949948346269665613440, -50309404951410650814014074576558854003173962007911839778845154074254777922662880], [-37006525356599614780712401500221287286403189604651479673705271743745595599980058367561263499804163724, 19185497097299157631909444903016730891863961235557618090990062404985510633680035235753952676, 400978239708857136994846424086956650645361275675392089339267946727604137315893626882, -23415941347660663077555199972169424499325319014544688683280525587681462949388194632, -34852036709784783444528065336996506789211028223770727527594233658728936116024250], [30881555775205428692009153569808329055096009069337181320432963779050260814352775605316608494765464254, -17536367289969246714151962170187298769200822734455230924692957636733680523482508035982388104, -459547284486843270703550001350032631372369719512738147831003889305273959095128390308, 10785621011169650079263806793492213270745556186885849858105051706015035444532001040, -6145538741243246122476912668591677259964970030200717685101966536917507159625580], [-54970338124236151936305940624898893981868185270128725884374578153639536477821972584649418676469846217, -21135190847893769228871060796890111744390831955961892734817876926414952955646152251785704370, -106816471076725326256306770556088255764906825084079045728230355487183321308365755745, -59205472493129157534704837835989963811238263582366018263691737787068196917877757020, -77957993569430638782746266749893629656171095101809853405882987947747796590977955], [10937350485299021369974929197790734615944481440574009470948175103151759041420004512711627385522937554, -50613507327958349405825882465858050231310229859124558377776353012759319392529936124016018680, 141376097831725628778732190415476808262929057878852842285062979151343113609948479588, -10448719414098095933451867850488310393630436338561217319128884096397027669202274320, -66190035921394052311027305142343385804193024490982491145576990518819600103595860], [-40244880427912514562701524380468352862222387239383911495864642120135365349690574424806559439322792892, -50194849867507894104805608158697679508112605772206198244149860661510601742865314929231682810, 278225636055802817111773523477895766161939634184589894253114288107332449657029795026, 66511256016826209516513286261502339494721758653185915763996793421195301008971985520, 169230397222202025240388563802534218952693090996472937016679323635021185235008460], [65350544567185215530335993356844047859824710447023967571141389474096632135156201619283541305934408894, -1399596543133145106937222490307924574213042020896111545806873897116026533272803113267439808, -153032347008052400165451799467483608851209580506971846761885165255637110408298523744, 1929894800190093613736098170084235075406674096274932810052260452828084665256170880, -21234429849755721177608510022498970409415195239029899859308715026111649862313760], [-4689389963003830886651053111441229742037593465826566168355120096903814601962359744081407713984147836, 2405158895024484542058763984900639220438994819698132844249665819547755762169887050267288009, 663319308211130302056515789394311432974004715078533779205536103035340311989798558273, -107950510105148781801493981600091572745185955457498221675322497580096289650912003968, 50965959887349739324850028301761203598700719852889121423784410171450463550668960], [18456562576979549199896086386306291401055236047330511041905551314303322422579873729756721860192821796, -5035947921632667170515907401132405226832117491538222813245177628237169429363158154978857738, -1004272132776113664993565970075586348144223260247517973988423493259203506412966695710, -62995597598939541377537897612482378746205255489901501256000008774011173268511124240, 113629442009962247699689012358039673737893363149400750242757615289841030501791980], [-50368389731356857124120888611625531984476952936664183491891716641377220538965913438732197202410612968, -56049934096163871980685413356584460050389887623310821005180417094688115521056124905003943300, -13437590191701932756378597370089756132966727326406296960183448125893820940067694300, -33422017937920212821394234405950404150695495650678575461056357459718820365898968800, -18186970840335811383679566172599766787945891371473335125782552970252402266418200], [-25786112574856886877942193902745831428668002250221066233409024714745211271891519102414995189951904543, 39832683905191639979452259792070770554342849740449258572786018038767752141476116600618278994, -89603864440047269780011002429776952680118206129857473537123881944510098286314533135, 159426421979631549293161574007931636888433123675391175364407845605516213476771533340, -48440669164288062565147236248118297425508140037822067327787136883150583625845805], [-34328677402008584825131902415236673137156361095736525776538666688859163560746304816050814968832504004, 6796721824679371601846888754894247682297459269870255975922823141303040453989698481783856775, -1247253769674050940543888938032875511250115211697430388889563392006074678846940648433, -52157560503615396143688756282595487111276324169558776894363336946126343471162527360, -191572400560232673008487005349411365331225779841821002994739213430994845012661280], [-51284081495881287419604721607685483488963546870121911263664087554560369104049244623293991362118932000, -64861934740145760832782483064172364570187362393386561136966719186954444632381335439312448992, 1248264484852709116374762642994119284377212895688369039454521353256479453572651148032, -61261702307350052242607878104163185822762090585536394417076438649564956047756393600, 130762990946496747304805850694950085672980682017946340503504274984881412114287200], [24467368938586707264444918156792383280255225980325725524146990585902054775301844211949526061328660106, -28429285725754591327529195888192425056430733194614380894911663555540468933081945724044672464, 103518916128730098512414677451072739769653090311350237841073133214395049777040699992, -21047939770516787816167184041657336439512242859546014073467235966033841926119551072, 44873038377440763792735493326647952726832258679719907148121841073655305622623240], [-105129099885269256047284821709274211633282395643910755518643198796286098010348199551811640112766918417, -34180612331940937576711439838753507882444050320527667078031061752443494340136782676783536466, -375870463867490729398606084620684885328319264725984780084393400950498072675341113073, 86692930011607923658806156506859225422347378673779111194311143932450111751777366500, -141134002283337881339978632240171687306433230842610607380503993605398874579889875], [-39660743615996445239458663650225854196776007830930404561606799591726287407812872694451839187958790340, 59989163234860141556692398417141741123756096345983524337069130743704088282764695138027407925, 713837424109320876103046492462089424013966624299394854955808110987311043599234286645, -71640966379061046991627119083019538018957404861764456164309139122943416604612110560, -185077500232400705599733757293109994246022273691208689601640893024578520769993880], [-43726147908391689467250115574448594869349850148450384354797952235086629363863284249749488240113546764, -101021796906725614135796722310003422929905615643540173313903132025411016296096600227562035547, -632555813159510045975257322313996276346300487110107467457612977311919843801112058691, -98775887676936750168981459298213478099076836162768310985528656452720133346072173440, -320501627917657438007878951360109676481792903666167410910169126156705709972097120], [-56427476872107173276777486002303283418023663272030251954464549982647670522651244670443609390810763252, -79434600968177309419327259328043061950885656878869799421083057545921336346389666649798071670, -818297333924408493830491583309615897182040067676396873726664264269444056448600957170, 105581602014403617640866377217410737837658384370765251892393347465477720707398697680, 36156177151838413387551336592788570641241217193458335845313492500929269102817220], [-81369348161132465610698656021514574429469309880077949812774374532428296970947784313042682270704555426, -169154304666922425945202402602736793720138674476502994862658773925978556022982380089124834952, -297788383007559026253833947238695056709188297478747008581447447745322881637567975460, -21725221828815397774576695996200554099353476516843719799700851400890035456962068720, -9380813943482566640569728887320972468697648570270564383406791354538876422062060], [101410712430699191420367658013735640764586579743827091711356514882071266956611561651469990299858415408, -26472123516475324890430705825443525798633133633765791925514232863583195192843641608448298712, 1245922599553104377765070014702446370063017698494846575656194402461974286034976883256, -112830156564248289213718378619820880007830229642471047558147084739695894053550700736, -5202157092451719267661055057111024314866193516514710738647834001120579100632560], [-100773517845200019278926396116233780437614276112828681513289712591700141215280860903122495283284931502, 119114373538702143504399240153736420388224473684416983049479936377142187949058064662450708168, -46080232535461348222560687166455541021254580973976216961711336206774765310516907964, -209355309718979458197434094057712847179860686825511498249121713365281624727235693456, 221231288693566349575328275679088423298420328455832066573478873880537034168989260], [154308357192056285687751563573128961946319702007544158424327874460975335000176969007788239768738667212, 34290042273231658652300343446036251600044377341685570473742061613302412423329337216725961955, -64673610991836829365540789561319881736001366358918399354879961669647762351787433045, 104945675070434404495079929034934547308761799866002588090224362289951875939569991680, -295245620958713929982484643003978288122602297425690388781293079197598432673505280], [-70482387026232227558659010567717113674710864467672380894539154300631919361911280191454401203170818777, -241362234861855253169805268972481170116847083759539550926173025087236564871509720406305716130, -1701988835084097357414673769813936640098002094319542457005095701054174817621530140505, -51978364444332281677005208552017212644150696686782177945791831824453941747148889980, -72531927971794637269460542661214004492158924611465258611506849039662385963894795], [-7212072676278212044061744480115557491259999864310505936249261794849159570580360650213822778957435855, 79970009004181003312712382517831158330721623773196175230888296252396136267435651021520883490, 317670284874071250029300450970815905347620849685696589870362656294174081322570821465, 75173413744824587799620136978338769406325461744147967812967164803561546202243727740, -103502550928765719254560851816325360315790120871065876565828516316195394186581365], [205348396112446318600981488896560010683055332173775868175962241050087197017333786708052777613784770172, -257163230040049070969381482500708326291801392663286793734635459666051235273772443877236194572, 459843974140791998276193602298457194996291967140470204056184803624010032666953420906, -39647051413058900603198726471012471646186749209583945157698569672649663301824822760, 132247408371875475131865057089296882713762895200689865662557526724148763395398270], [-142991314994769032554257228942412288610192956805863137851279870782879622568472617693268426620670564936, 69855685099467714483821547616546838352593255163971141539946281926042610635601822032473684596, -1184242780548452054845125546231304616122412286221384851806948331785698896211243746788, 30759137126646466572537096294194317738464914692759286894345017489334643700997685280, 535918833906784001215941974986653559420151458107323105945103781611426933059062440], [-51149176211369104882449323254636100644134444699473798991984604304722827860611006261868685572716707582, -109905156040702446052718888324987910078669341132545355358308011592908201746876286000707003064, -354720930096522763745330178074120591698956245679971859038863594240140749692223837820, -250036373025748311433924320344707628421512515860307703716962121857160304949976406160, 92832246894264297869391676065006680648175539105699048204300342647686500406583820], [429787736523006900782439487791351757944448244010387080143133989169259237976673832726369309484290757379, 150566594086772920599657252160943111809350466122730681594544664739808019742063842494812313574, -289731730185652889354676277188695166822318974791349421230716939919599087298822220597, 203793674055408160187356633027118214856291475143134482649172514917283376690896072052, -421711193933204663570246362121568933798771357487000707391281614703192353028835615], [176302502608910826152747821229474662851234579483994956110363084741397397112568074014547062575663273212, -353653678818415543405556350966504810731944041580776176124456985727733265276673476784054649750, -2208732309781148473435165736687378347096156035283788609302808957132187407084489681250, 172088360855711202810907008160272485034344952845357240747834759161438144463078106000, 450673502138517035780231543077688667515983703516117465838130636881877060023064500], [182475184341586494487833898593062788845244129232662040650463533285828224126585514834899693847140317813, -20175379911467432324450125488618420739584748811369822157394630343326315612442213811172584870, 2775061480845560483535981674379196624074463818751583392647974795107366894979199651221, -623373861939488042692836138041608094645014902457280244940915625024833168300409368820, -71421464377557730831313012968663481861248484071729008613800761944235669214449985], [266825034357974951453304576359233678841553718612564951470537697920575656349806425859751584403907073908, 262047562088425667173475754592965905128454784983054928306397002563411438488986581665984163620, 3879325082701850137711344256015648960341739418461185416275206429730594224790510898370, 395098943608191515324652042524176436216567671971915010338962036889249708493128110520, 410990241352527062323796610098320076685816368325622416130789492172904098104925830], [-184576184881444764154676942906818632200868624422971305033242140191856622324704272412455595224786342892, -43448559414952928473810477842392183523937517709966025295439870741432005278415488504608252323, -5995265158266140672562230966019091182024985489736236226438086309251774854258935191051, 361014293455674276744310509599794892586393358276380906625861569038497134727629516160, -627847385469780235719310224142982098679605209605887659055586997290205170590636320], [435983890543269495176314587006308315886825766201106966476339463555642395949114481730624847961304790932, 236217544608638202307613216076537054460580078450272488805296405868547850225713176238859459007, 1504281631176480249012146525656639947103755480694871419642389285512038517492408816799, 148217751546817390594840531982537381415610447579270725704658698999461869457806334176, -126311744499396617700963004202844264362095747619721901984071271407090989852669800], [309118040160578751529844775136297344645934923983699434710515232526390288503992968869572843857427018426, -327108711594211101300685679445022426599519178465798534833414813233006817248509262974790678480, -1133501788351737777883406491436508307356871863906008874514075047369679996644423187368, 723288604462239042265961821268941267534714616542008611326786100445157534880419250080, 103921986966160999333135074724913624660894279367240988077147600104517878383992840], [-528348547503019648042326486085211820127717524446249109489011828064391577272020955756128978596879913865, 709853554757280229378272893289549065018043236121903227720222107225927202018924505644990342398, -4806337899152527269048189810165725047713123452170888463562997712962345826813120882313, 474648745410056260009917161225127299446656813308444845407473655100802180611283821380, 159044760451515106448767293949219437331501799965814806853034572789611564317643365], [542484217011504605286846626754368954133396083566064665726428709236785187759294420054494161742988343268, -131431575690161763745976321060013912336812865658737956902835481675767569383100708680111647631, -3869361781099233877801538586844797739855470124214791491355096962547464864268442899863, 633820679977445508248738591866506287153036508527051171720516378795236773938625148800, -1135500808020017680277611993166062266224307647656275158665847681888632457855677600], [76617483769576857711439470526087239025069681722511296370067549822835452088867153968086250025117679652, 405345959291782773533783590869839908633285393294573947479068187692117524007862483879224917625, 4501565755727968409429092509567546634888792181148679236475772638075820118670594748625, -342475795050760909277448375777763994628610009729497726891420678623092430366115776000, -187665752302159692708624811928592113558438557758165439367479813027273331430576000], [-189908088443014244628706272865930990208497100114999164868603688227396250920696406839255965280925817804, 457333855471091025221804784255056442312689131806048935916916935412311916736532069944167793628, -1731270880046390363849084217525033321309626582293532759865747089505191210666812689346, 585259455132364477227977463154323176048659390840537501541265715468824916015236925000, -67262132790625261673142027385441783997652479780153068762770692178238299368943750], [603687048720207766638847880472418142333718190724710223119741061102967253837345170064079562942191019003, -509434959081235057768532131920971678324250378649401696907193526576311336127458330009708510010, 961720713846306093296791977103601213805842027042566038540682847792167879231795253115, -194788398787616080893814556596460475507488448386475094416074679068995069577443376460, 841181392985776770752730959888978859312228487184233277649714726002176258497628785], [-273539176989187465009634331404778220260459899603388977336074523652340027579250188793723089769008827872, 466937085891210450218144070419204087984299602591049295710768725389404217952853062521234538288, -8594102569785420221168512447753596163359087771279420497374999675535016008563329377904, 469948907609886679894792574048731962187780629546167602345473907007407997224842601344, 1390576706952078655017265899193821352644407689806378588229167375481279286097539680], [533931759465918354066887424186932856076602380133577640325075796009078416765999947067127105776415029260, -667523807356709265066695642677600236581521941679893212123281084189214188594351552511222483198, -1957580926386503619416073285879017043047075033531456439492590971756648354927447962522, -910271817864176355198880163741750354318399772667566733311127649418899711289283982000, 1338751363257536476401678775296279856874303850488078602012812009269092559774326500], [575414248089291446849770187622604626158011367145825385144574193167443807881911644814699553433936423412, 943613911428605001245476384326558660236079788778968045058689020791546082030971196337821788900, -4757636662689616843614349924849652164519950795331429963150342339635890394523167199326, -1126223268700016543730524575222492851249582886513147467070469863075003995317863917000, 62166064370629318662068921034079059238032979773525683072681187028385519877587750], [-454377109283840959735415005076361876170402036810123455388798780508510548258297512814788664186008260788, -856798885797857360518438884123026105012059397855789905187712608956442319715157738162181280102, 7671857597490363220338044235000529173037178091312299715551066750673036759532830577566, -341863838644773557895755734191455113624916938873262519404770443401014189283275800880, -1134036166317001983844452112120405148930670824739498340255362992777916639506023740], [-39976984019785135254763136694176461240314531606575596144468953768680714262625718120494815951172533069, -540356983133158528155621245994693813893973010572564029777736743576535958747033663919741382794, 9212519582734778982273449746372740219477383637012127273064763731800614379212339352467, -1268598943156913468460112955105889162222966805286799437156146128968976209141030482092, 628440137657519108715602939589116219952439751906198194705297187225278259708157625], [-546789578566720672497900475313194143481330487891837030325383262439479313652780484704461335248036097031, -517030238169359355534050247585960357917361356787006199539870688202981441823255180564599068414, -12195736351904676118163813920248627133180314377173843716634390739961070998494144234743, -1351411339106073851931853839193410797132253653567398767334739021467361752389328091460, -802818601086692415914738805329049882902012397203241821565161254545374600152991205], [121349729624879710932511391145697348740831669401239008810665914426366993700002386820546296980643778408, -1884679719369695819411357188706849604290369895100601192531819799248319300593600103036594418364, -7159565772233232899786142338736318215347450674836629398627794946187549581432086599140, -249265351714450907926166455513874261606142567971200826734485015680981958389952256800, 1704174213666732565522624579456537565279957897199063944300111419488892957218248600], [-1182050126552525750442854351725822611444249129075519711534217294144638628723829522764810550655505003596, 1278725248900509663553925610890865622121034653284855174693738051869289014682762667317210283609, -4789404793467150998967519532029114234892663649835113922620230292477445093486921240447, -392341410079081866395297556368411110639039696949657976020432923446068336259853142208, 266800947879501620306650330743262342860267040222324582266676085860962281161229840], [-261210111594065443021443305624390670331229368350370230442856184347807898635026449016440622042248522562, -1876140855211662230659408782589449700779337680604256605093648107734984217647371538542906764328, -3855237845322611688367085665324999156604057684332950920205546909044662956209133048436, -1706886576433748141833508548615950490793972979093570122487866773622107943463863866800, -160458440534987230268077524838140722592839290387680620957843375103171346803783900], [1645424437025210914138040612536727601718045603069877916254680260908878800390995249773812964638725086819, -349904270821167516908121047129917099619843597154202956130070120385265813029024952954184644618, 5400184762890188368336783221463693677577186096110865037358521907444820942182763403091, 528359752898756326421369253436864703765437355667888995902726392859699622929257256020, -651931624597979116819142393704977073173910027988735263742810446536101990503409415], [1260153006938354561519355095359587214381503192461915070956505152817587585417854133369283359184391978596, -842361556777433013576075215078704653052946358480213539108334101193183278760629272829224733333, 7270503249849869761930515518043091257721296330949158804036732869883064993875421229835, 625658829273018013175570763671314166158197610982262573462052043047722253230243327840, 1418941598385199483409892400346874817200546463918206355482618980080901926941083320], [748656990545601191593484455129838213825291963126216353540042748723933648097327749616082199933418378372, -166957708830639647968415117151419618644272877761306690564157029244118877149785388997351712428, -6748313683676691426761649628322556002989070376417213023458546486973324520663995046246, -597180331100321994300913995880116894985296881293947859197477114021214404886876532904, -826139329263062334102522375145743522741762702183890877389521006755744982603480050], [-1982992396994222709720683970079341927741122168639632535314438947052398569364157244622719015059317706828, -1770928817513221521126355225076949933091972350812912966800784761687153418495804628548462322945, -5640460803695447517341401091140954862499144027893491467012275044931200699022598018945, -265346709539802142820312883301318641842266650334701539151034106805793995511027650720, -1941663672296026229619180641458132025908359218409406812635206916609565453957527880], [-4220004044418153692697514486869223975530165714609893829709126683381797702929468715280393174936009908260, -1817894019615678172967139341884142263599821047318305790649476114547359751995296875056542033470, -629686610013143244320620735803980537195324199875547237450985742381904263953299268170, 2585601324119497731260056514486072534123324282613966378149642301925259078335134894480, 748260500058318928846646155505289883957243217765784133362904426988599817792384820]]
